#ifndef lint
static const char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
#endif

#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYPATCH 20130925

#define YYEMPTY        (-1)
#define yyclearin      (yychar = YYEMPTY)
#define yyerrok        (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)

#define YYPREFIX "yy"

#define YYPURE 0

#line 26 "ircd_parser.y"

#define YY_NO_UNPUT
#include <sys/types.h>

#include "stdinc.h"
#include "ircd.h"
#include "tools.h"
#include "list.h"
#include "s_conf.h"
#include "event.h"
#include "s_log.h"
#include "client.h"	/* for UMODE_ALL only */
#include "pcre.h"
#include "irc_string.h"
#include "irc_getaddrinfo.h"
#include "sprintf_irc.h"
#include "memory.h"
#include "modules.h"
#include "s_serv.h" /* for CAP_LL / IsCapable */
#include "s_misc.h" /* for certfp funcs */
#include "hostmask.h"
#include "send.h"
#include "listener.h"
#include "resv.h"
#include "numeric.h"
#include "s_user.h"

#ifdef HAVE_LIBCRYPTO
#include <openssl/rsa.h>
#include <openssl/bio.h>
#include <openssl/pem.h>
#endif

static char *class_name = NULL;
static struct ConfItem *yy_conf = NULL;
static struct AccessItem *yy_aconf = NULL;
static struct MatchItem *yy_match_item = NULL;
static struct ClassItem *yy_class = NULL;
static struct DnsblItem *yy_dconf = NULL;
static char *yy_class_name = NULL;

static dlink_list col_conf_list  = { NULL, NULL, 0 };
static dlink_list hub_conf_list  = { NULL, NULL, 0 };
static dlink_list leaf_conf_list = { NULL, NULL, 0 };
static unsigned int listener_flags = 0;
static unsigned int regex_ban = 0;
static char userbuf[IRCD_BUFSIZE];
static char hostbuf[IRCD_BUFSIZE];
static char reasonbuf[REASONLEN + 1];
static char gecos_name[REALLEN * 4];

extern dlink_list gdeny_items; /* XXX */

static char *resv_reason = NULL;
static char *listener_address = NULL;
static int not_atom = 0;

struct CollectItem {
  dlink_node node;
  char *name;
  char *user;
  char *host;
  char *passwd;
  int  port;
  int  flags;
#ifdef HAVE_LIBCRYPTO
  char *rsa_public_key_file;
  RSA *rsa_public_key;
#endif
};

static void
free_collect_item(struct CollectItem *item)
{
  MyFree(item->name);
  MyFree(item->user);
  MyFree(item->host);
  MyFree(item->passwd);
#ifdef HAVE_LIBCRYPTO
  MyFree(item->rsa_public_key_file);
#endif
  MyFree(item);
}

static void
unhook_hub_leaf_confs(void)
{
  dlink_node *ptr;
  dlink_node *next_ptr;
  struct CollectItem *yy_hconf;
  struct CollectItem *yy_lconf;

  DLINK_FOREACH_SAFE(ptr, next_ptr, hub_conf_list.head)
  {
    yy_hconf = ptr->data;
    dlinkDelete(&yy_hconf->node, &hub_conf_list);
    free_collect_item(yy_hconf);
  }

  DLINK_FOREACH_SAFE(ptr, next_ptr, leaf_conf_list.head)
  {
    yy_lconf = ptr->data;
    dlinkDelete(&yy_lconf->node, &leaf_conf_list);
    free_collect_item(yy_lconf);
  }
}

#line 135 "ircd_parser.y"
#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
typedef union {
  int number;
  char *string;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
#line 139 "y.tab.c"

/* compatibility with bison */
#ifdef YYPARSE_PARAM
/* compatibility with FreeBSD */
# ifdef YYPARSE_PARAM_TYPE
#  define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#  define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
# define YYPARSE_DECL() yyparse(void)
#endif

/* Parameters sent to lex. */
#ifdef YYLEX_PARAM
# define YYLEX_DECL() yylex(void *YYLEX_PARAM)
# define YYLEX yylex(YYLEX_PARAM)
#else
# define YYLEX_DECL() yylex(void)
# define YYLEX yylex()
#endif

/* Parameters sent to yyerror. */
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(msg)
#endif

extern int YYPARSE_DECL();

#define ACCEPT_PASSWORD 257
#define ACTION 258
#define ADMIN 259
#define AFTYPE 260
#define T_ALLOW 261
#define ANTI_NICK_FLOOD 262
#define ANTI_SPAM_EXIT_MESSAGE_TIME 263
#define ANTI_SPAM_CONNECT_NUMERIC 264
#define AUTOCONN 265
#define T_BLOCK 266
#define BURST_AWAY 267
#define BURST_TOPICWHO 268
#define BYTES 269
#define KBYTES 270
#define MBYTES 271
#define GBYTES 272
#define TBYTES 273
#define CALLER_ID_WAIT 274
#define CAN_FLOOD 275
#define CAN_IDLE 276
#define CHANNEL 277
#define CIDR_BITLEN_IPV4 278
#define CIDR_BITLEN_IPV6 279
#define CIPHER_PREFERENCE 280
#define CLASS 281
#define CLIENTCERT_HASH 282
#define CLOAK_KEY1 283
#define CLOAK_KEY2 284
#define CLOAK_KEY3 285
#define CLOAK_WHOIS_ACTUALLY 286
#define ACCOUNT_WHOIS 287
#define COMPRESSED 288
#define COMPRESSION_LEVEL 289
#define CONNECT 290
#define CONNECTFREQ 291
#define CRYPTLINK 292
#define CYCLE_ON_HOSTCHANGE 293
#define DEFAULT_CIPHER_PREFERENCE 294
#define DEFAULT_FLOODCOUNT 295
#define DEFAULT_SPLIT_SERVER_COUNT 296
#define DEFAULT_SPLIT_USER_COUNT 297
#define DENY 298
#define DESCRIPTION 299
#define DIE 300
#define DISABLE_AUTH 301
#define DISABLE_FAKE_CHANNELS 302
#define DISABLE_HIDDEN 303
#define DISABLE_LOCAL_CHANNELS 304
#define DISABLE_REMOTE_COMMANDS 305
#define DNSBL 306
#define DOT_IN_IP6_ADDR 307
#define DOTS_IN_IDENT 308
#define DURATION 309
#define EGDPOOL_PATH 310
#define EMAIL 311
#define ENABLE 312
#define ENCRYPTED 313
#define EXCEED_LIMIT 314
#define EXEMPT 315
#define FAILED_OPER_NOTICE 316
#define FAKENAME 317
#define IRCD_FLAGS 318
#define FLATTEN_LINKS 319
#define FFAILED_OPERLOG 320
#define FKILLLOG 321
#define FKLINELOG 322
#define FGLINELOG 323
#define FIOERRLOG 324
#define FOPERLOG 325
#define FOPERSPYLOG 326
#define FUSERLOG 327
#define GECOS 328
#define GENERAL 329
#define GLINE 330
#define GLINES 331
#define GLINE_EXEMPT 332
#define GLINE_LOG 333
#define GLINE_TIME 334
#define GLINE_MIN_CIDR 335
#define GLINE_MIN_CIDR6 336
#define GLOBAL_KILL 337
#define IRCD_AUTH 338
#define NEED_IDENT 339
#define HAVENT_READ_CONF 340
#define HIDDEN 341
#define HIDDEN_ADMIN 342
#define HIDDEN_NAME 343
#define HIDDEN_OPER 344
#define HIDE_SERVER_IPS 345
#define HIDE_SERVERS 346
#define HIDE_SPOOF_IPS 347
#define HOST 348
#define HUB 349
#define HUB_MASK 350
#define IDLETIME 351
#define IGNORE_BOGUS_TS 352
#define INVISIBLE_ON_CONNECT 353
#define IP 354
#define KILL 355
#define KILL_CHASE_TIME_LIMIT 356
#define KLINE 357
#define KLINE_EXEMPT 358
#define KLINE_REASON 359
#define KLINE_WITH_REASON 360
#define KNOCK_DELAY 361
#define KNOCK_DELAY_CHANNEL 362
#define LAZYLINK 363
#define LEAF_MASK 364
#define LINKS_DELAY 365
#define LISTEN 366
#define T_LOG 367
#define LOGGING 368
#define LOG_LEVEL 369
#define MAX_ACCEPT 370
#define MAX_BANS 371
#define MAX_CHANS_PER_USER 372
#define MAX_GLOBAL 373
#define MAX_IDENT 374
#define MAX_LOCAL 375
#define MAX_NICK_CHANGES 376
#define MAX_NICK_TIME 377
#define MAX_NUMBER 378
#define MAX_TARGETS 379
#define MESSAGE_LOCALE 380
#define MIN_NONWILDCARD 381
#define MIN_NONWILDCARD_SIMPLE 382
#define MODULE 383
#define MODULES 384
#define NAME 385
#define NEED_PASSWORD 386
#define IS_WEBIRC 387
#define NETWORK_DESC 388
#define NETWORK_NAME 389
#define NICK 390
#define NICK_CHANGES 391
#define NICK_COLLIDE_REALHOST 392
#define NO_CREATE_ON_SPLIT 393
#define NO_JOIN_ON_SPLIT 394
#define NO_OPER_FLOOD 395
#define NO_TILDE 396
#define NOT 397
#define NUMBER 398
#define NUMBER_PER_IDENT 399
#define NUMBER_PER_CIDR 400
#define NUMBER_PER_IP 401
#define NUMBER_PER_IP_GLOBAL 402
#define OPERATOR 403
#define OPERS_BYPASS_CALLERID 404
#define OPER_LOG 405
#define OPER_ONLY_UMODES 406
#define OPER_PASS_RESV 407
#define OPER_SPY_T 408
#define OPER_FARCONNECT 409
#define OPER_UMODES 410
#define JOIN_FLOOD_COUNT 411
#define JOIN_FLOOD_TIME 412
#define PACE_WAIT 413
#define PACE_WAIT_SIMPLE 414
#define PASSWORD 415
#define PATH 416
#define PING_COOKIE 417
#define PING_TIME 418
#define PING_WARNING 419
#define PORT 420
#define QSTRING 421
#define QUIET_ON_BAN 422
#define REASON 423
#define REDIRPORT 424
#define REDIRSERV 425
#define REGEX_T 426
#define REHASH 427
#define TREJECT_HOLD_TIME 428
#define REMOTE 429
#define REMOTEBAN 430
#define RESTRICT_CHANNELS 431
#define RESTRICTED 432
#define RSA_PRIVATE_KEY_FILE 433
#define RSA_PUBLIC_KEY_FILE 434
#define RSA_CRYPTLINK_KEY_FILE 435
#define SSL_CERTIFICATE_FILE 436
#define RESV 437
#define RESV_EXEMPT 438
#define SECONDS 439
#define MINUTES 440
#define HOURS 441
#define DAYS 442
#define WEEKS 443
#define SENDQ 444
#define SEND_PASSWORD 445
#define SERVERHIDE 446
#define SERVERINFO 447
#define SERVICES 448
#define SERVICES_NAME 449
#define SERVLINK_PATH 450
#define IRCD_SID 451
#define TKLINE_EXPIRE_NOTICES 452
#define T_SHARED 453
#define T_CLUSTER 454
#define TYPE 455
#define SHORT_MOTD 456
#define SILENT 457
#define SPOOF 458
#define SPOOF_NOTICE 459
#define STATS_E_DISABLED 460
#define STATS_I_OPER_ONLY 461
#define STATS_K_OPER_ONLY 462
#define STATS_O_OPER_ONLY 463
#define STATS_P_OPER_ONLY 464
#define TBOOL 465
#define TMASKED 466
#define T_REJECT 467
#define TS_MAX_DELTA 468
#define TS_WARN_DELTA 469
#define TWODOTS 470
#define T_ALL 471
#define T_BOTS 472
#define T_SOFTCALLERID 473
#define T_CALLERID 474
#define T_CCONN 475
#define T_NOCTCP 476
#define T_CLIENT_FLOOD 477
#define T_DEAF 478
#define T_DEBUG 479
#define T_DRONE 480
#define T_EXTERNAL 481
#define T_FULL 482
#define T_HIDECHANNELS 483
#define T_FARCONNECT 484
#define T_INVISIBLE 485
#define T_IPV4 486
#define T_IPV6 487
#define T_LOCOPS 488
#define T_LOGPATH 489
#define T_L_CRIT 490
#define T_L_DEBUG 491
#define T_L_ERROR 492
#define T_L_INFO 493
#define T_L_NOTICE 494
#define T_L_TRACE 495
#define T_L_WARN 496
#define T_MAX_CLIENTS 497
#define T_NCHANGE 498
#define T_OPERWALL 499
#define T_REJ 500
#define T_SERVNOTICE 501
#define T_SKILL 502
#define T_SPY 503
#define T_SSL 504
#define T_UMODES 505
#define T_UNAUTH 506
#define T_UNRESV 507
#define T_UNXLINE 508
#define T_WALLOP 509
#define THROTTLE_TIME 510
#define THROTTLE_NUM 511
#define TOPICBURST 512
#define TRUE_NO_OPER_FLOOD 513
#define TKLINE 514
#define TXLINE 515
#define TRESV 516
#define UNKLINE 517
#define USER 518
#define USE_EGD 519
#define USE_EXCEPT 520
#define USE_INVEX 521
#define HIDE_KILLER 522
#define USE_REGEX_BANS 523
#define USE_KNOCK 524
#define USE_NOCTCP 525
#define USE_LOGGING 526
#define USE_WHOIS_ACTUALLY 527
#define VHOST 528
#define VHOST6 529
#define XLINE 530
#define WARN 531
#define WARN_NO_NLINE 532
#define YYERRCODE 256
static const short yylhs[] = {                           -1,
    0,    0,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    5,    5,    5,    2,    2,    1,    1,    1,
    1,    1,    1,    4,    4,    3,    3,    3,    3,   25,
   27,   27,   28,   28,   28,   29,   30,   31,   26,   32,
   32,   33,   33,   33,   33,   34,   35,   36,   13,   37,
   37,   38,   38,   38,   38,   38,   38,   38,   38,   38,
   38,   38,   38,   38,   50,   46,   47,   39,   49,   42,
   43,   44,   40,   48,   45,   41,    6,   51,   51,   52,
   52,   52,   52,   53,   55,   54,    7,   56,   56,   57,
   57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
   57,   57,   58,   59,   62,   69,   63,   67,   64,   65,
   68,   66,   60,   60,   60,   60,   60,   60,   60,   61,
   71,    8,   70,   70,   72,   72,   74,   74,   74,   74,
   74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
   74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
   74,   75,   73,   76,   96,   77,   94,   95,   81,   99,
   80,  100,  100,  101,  101,  101,  101,  101,  101,  101,
  101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
  101,  101,  101,  101,   82,   83,   89,   84,   85,   86,
   87,   88,   90,   91,   92,   78,   79,   97,   93,  102,
   98,  103,  103,  106,  104,  107,  104,  105,  105,  105,
  105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
  105,  105,  105,  105,  109,   10,  108,  108,  110,  110,
  112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
  112,  112,  112,  112,  113,  111,  116,  117,  119,  120,
  121,  122,  123,  124,  125,  114,  115,  118,  126,   11,
  129,  128,  130,  130,  131,  131,  127,  127,  132,  132,
  132,  132,  132,  137,  133,  136,  136,  138,  138,  134,
  135,  139,   12,  140,  140,  141,  141,  141,  141,  141,
  141,  141,  141,  141,  141,  141,  141,  141,  141,  141,
  141,  141,  141,  141,  142,  143,  159,  152,  144,  158,
  160,  145,  161,  161,  164,  162,  165,  162,  163,  163,
  163,  163,  163,  163,  163,  163,  163,  163,  163,  146,
  147,  148,  156,  149,  150,  151,  154,  155,  153,  157,
  166,   15,  167,  167,  168,  168,  168,  168,  169,  170,
  171,  172,   16,  173,  173,  174,  174,  174,  174,  175,
  176,  178,  177,  179,  179,  180,  180,  180,  180,  180,
  180,  180,  180,  180,  180,  180,  180,  180,  181,   17,
  182,  182,  183,  183,  183,  184,  186,  185,  187,  187,
  188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
  188,  190,   18,  189,  189,  191,  191,  193,  193,  193,
  193,  193,  193,  193,  193,  193,  193,  193,  193,  193,
  193,  193,  193,  193,  193,  193,  193,  194,  192,  195,
  196,  197,  198,  200,  199,  199,  201,  213,  202,  214,
  214,  217,  215,  218,  215,  216,  216,  216,  216,  216,
  216,  210,  207,  209,  208,  206,  212,  203,  204,  205,
  211,  219,   19,  222,  221,  223,  223,  224,  220,  220,
  225,  225,  225,  225,  226,  227,  228,   20,  229,  229,
  230,  230,  230,  231,  232,   21,  233,  233,  234,  234,
  234,  235,  236,  237,   24,  240,  239,  241,  241,  242,
  238,  238,  243,  243,  243,  243,  244,  245,   22,  246,
  246,  247,  247,  247,  247,  247,  247,  247,  247,  247,
  247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
  247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
  247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
  247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
  247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
  247,  247,  247,  247,  247,  247,  247,  301,  302,  299,
  303,  312,  304,  300,  259,  248,  249,  288,  250,  251,
  252,  253,  254,  255,  256,  257,  258,  295,  260,  261,
  306,  307,  308,  309,  310,  311,  262,  263,  290,  265,
  270,  305,  266,  266,  268,  268,  267,  282,  283,  269,
  271,  272,  273,  274,  276,  275,  264,  278,  287,  289,
  291,  279,  280,  297,  298,  293,  294,  313,  281,  314,
  314,  315,  315,  315,  315,  315,  315,  315,  315,  315,
  315,  315,  315,  315,  315,  315,  315,  315,  315,  315,
  315,  315,  316,  277,  317,  317,  318,  318,  318,  318,
  318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
  318,  318,  318,  318,  318,  318,  318,  285,  286,  284,
  292,  296,  319,   23,  320,  320,  321,  321,  321,  321,
  321,  321,  321,  322,  323,  328,  324,  329,  329,  330,
  330,  325,  326,  331,  327,  332,  332,  333,  333,    9,
  334,  334,  335,  335,  335,  335,  335,  335,  335,  335,
  335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
  335,  335,  335,  335,  356,  355,  350,  336,  337,  338,
  341,  339,  340,  343,  344,  345,  346,  342,  347,  348,
  349,  351,  352,  353,  354,   14,  357,  357,  358,  358,
  358,  358,  358,  358,  358,  358,  359,  360,  364,  361,
  363,  362,  365,
};
static const short yylen[] = {                            2,
    0,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    2,    0,    1,    2,    3,    3,
    3,    3,    3,    0,    1,    2,    3,    3,    3,    5,
    2,    1,    1,    1,    2,    4,    4,    0,    6,    2,
    1,    1,    1,    1,    2,    4,    4,    4,    5,    2,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    5,    2,    1,    1,
    1,    1,    2,    4,    4,    4,    5,    2,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    2,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    0,    7,    0,    1,    2,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    4,    1,    4,    4,    4,    4,    4,    4,    0,
    5,    3,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    0,
    5,    3,    1,    0,    3,    0,    2,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    0,    7,    0,    1,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    4,    1,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    0,    6,
    0,    5,    3,    1,    1,    1,    2,    1,    1,    1,
    1,    1,    2,    0,    5,    3,    1,    1,    3,    4,
    4,    0,    6,    2,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    4,    4,    4,    4,    4,    4,
    0,    5,    3,    1,    0,    3,    0,    2,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    0,    6,    2,    1,    1,    1,    1,    2,    4,    4,
    4,    0,    6,    2,    1,    1,    1,    1,    2,    4,
    4,    0,    5,    3,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    0,    6,
    2,    1,    1,    1,    2,    4,    0,    5,    3,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    0,    7,    0,    1,    2,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    2,    4,    1,    4,
    4,    4,    4,    4,    4,    4,    4,    0,    5,    3,
    1,    0,    3,    0,    2,    1,    1,    1,    1,    1,
    1,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    0,    6,    0,    5,    3,    1,    1,    2,    1,
    1,    1,    1,    1,    4,    4,    0,    6,    2,    1,
    1,    1,    1,    4,    4,    5,    2,    1,    1,    1,
    1,    4,    4,    0,    6,    0,    5,    3,    1,    1,
    2,    1,    1,    1,    1,    1,    4,    4,    5,    2,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    0,    5,    3,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    0,    5,    3,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    4,    4,    4,
    4,    4,    0,    6,    2,    1,    1,    1,    1,    1,
    1,    1,    1,    4,    4,    0,    5,    3,    1,    1,
    1,    4,    4,    0,    5,    3,    1,    1,    1,    5,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    5,    2,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    4,    4,    4,    4,
    4,    4,    4,
};
static const short yydefred[] = {                         1,
    0,    0,    0,    0,  235,  412,  487,   48,    0,  504,
    0,  703,  292,  472,  269,    0,    0,  131,  351,    0,
    0,  362,  389,    2,    3,    4,    5,    6,    7,    8,
    9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
   19,   20,   21,   22,   23,   24,   25,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   89,   90,   91,   92,  754,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,  745,  746,  747,  748,  749,  750,  751,
  752,  753,  256,    0,  238,  439,    0,  415,    0,    0,
  501,    0,    0,    0,  498,  499,  500,    0,  587,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  673,    0,
  648,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,  544,  545,
  546,  547,  548,  549,  550,  551,  552,  553,  554,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,  577,  578,  579,  580,  581,  582,  583,  584,  585,
  586,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   99,
  100,  101,  102,  103,  104,  105,  106,  107,  108,  109,
  110,  111,    0,    0,    0,    0,   42,   43,   44,  163,
    0,  134,    0,  786,    0,    0,    0,    0,    0,    0,
    0,    0,  778,  779,  780,  781,  782,  783,  784,  785,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   61,   62,   63,   64,   65,   66,
   67,   68,   69,   70,   71,   72,   73,    0,    0,   93,
    0,    0,    0,    0,   88,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  731,    0,    0,
  493,    0,    0,    0,  490,  491,  492,    0,    0,    0,
    0,    0,   51,   52,   53,   54,    0,    0,    0,  497,
  516,    0,    0,  506,    0,  515,  512,  513,  514,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  520,  713,  724,    0,    0,
  716,    0,    0,    0,  706,  707,  708,  709,  710,  711,
  712,    0,    0,    0,    0,    0,    0,  321,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  295,  296,  297,  298,  299,  300,  301,  302,  303,
  304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
  484,    0,  474,    0,    0,  483,  480,  481,  482,    0,
  271,    0,    0,    0,    0,  280,  278,  279,  281,  282,
  112,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   98,   45,    0,    0,    0,   41,
    0,    0,    0,    0,    0,    0,  354,  355,  356,  357,
    0,    0,    0,    0,    0,    0,    0,    0,  777,   74,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   60,    0,    0,  372,    0,    0,  365,
  366,  367,  368,    0,    0,  397,    0,  392,  393,  394,
    0,    0,    0,   87,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  730,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  240,  241,  242,  243,  244,  245,  246,  247,
  248,  249,  250,  251,  252,  253,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  448,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  417,  418,  419,
  420,  421,  422,  423,  424,  425,  426,  427,  428,  429,
  430,  431,  432,  433,  434,  435,  436,    0,    0,    0,
  489,   55,    0,    0,    0,    0,   50,    0,    0,  496,
    0,    0,    0,    0,  511,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  519,    0,    0,    0,    0,    0,    0,
    0,  705,  314,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  294,    0,    0,    0,    0,  479,  283,    0,
    0,    0,    0,    0,  277,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   97,    0,    0,   40,    0,    0,    0,
    0,    0,    0,  210,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  170,    0,
    0,    0,    0,  136,  137,  138,  139,  140,  141,  142,
  143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
  153,  154,  155,  156,  157,  158,  159,  160,  358,    0,
    0,    0,    0,  353,    0,    0,    0,    0,    0,    0,
    0,  776,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   59,  369,    0,    0,    0,    0,
  364,  395,    0,    0,    0,  391,   96,   95,   94,  773,
  755,  770,  769,  756,  758,    0,    0,    0,    0,    0,
   27,   28,  764,  765,  768,  766,  771,  772,  774,  775,
  767,  757,  759,  760,  761,  762,  763,  254,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  239,  437,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  416,    0,    0,  488,    0,    0,
    0,   49,  503,  502,    0,    0,    0,  505,  600,  604,
  605,  590,  628,  611,  612,  613,  614,  615,  641,  640,
  700,  645,  598,  702,  637,  643,  599,  588,  589,  608,
  596,  636,  597,  617,  595,  610,  609,  603,  602,  601,
  638,  635,  698,  699,  592,  632,  629,  677,  693,  694,
  678,  679,  680,  681,  688,  682,  696,  697,  691,  695,
  684,  689,  685,  690,  683,  687,  686,  692,    0,  676,
  634,  652,  668,  669,  653,  654,  655,  656,  663,  657,
  671,  672,  666,  670,  659,  664,  660,  665,  658,  662,
  661,  667,    0,  651,  627,  630,  644,  593,  616,  639,
  594,  631,  619,  625,  626,  623,  624,  620,  621,  607,
  606,    0,    0,    0,   35,   36,  701,  647,  646,  633,
  642,  622,  591,  618,    0,    0,    0,    0,    0,    0,
  704,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  293,
    0,    0,    0,  473,    0,    0,    0,    0,    0,  287,
  270,  116,  122,  120,  119,  121,  117,  118,  115,  123,
  129,  124,  128,  126,  127,  125,  114,  113,  130,   46,
   47,  161,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  135,    0,    0,
    0,  352,  792,  787,  791,  789,  793,  788,  790,   80,
   86,   78,   82,   81,   76,   77,   75,   79,   85,   83,
   84,    0,    0,    0,  363,    0,    0,  390,   29,   30,
   31,   32,   33,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  236,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  413,  494,  495,
   57,   56,   58,  517,  518,  510,    0,  509,  674,    0,
  649,    0,   37,   38,   39,  729,  728,    0,  727,  715,
  714,  721,  720,    0,  719,  723,  722,  343,  319,  317,
  320,  342,  325,    0,  324,    0,  345,  341,  340,  350,
  349,  344,  316,  348,  347,  346,  318,  315,  486,  478,
    0,  477,  485,  276,  275,    0,  274,  291,  290,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  132,  360,  361,  359,
  370,  376,  387,  382,  386,  388,  385,  384,  381,  377,
  380,  383,  378,  379,    0,  375,  371,  396,  401,  407,
  411,  410,  409,  406,  402,  405,  408,  403,  404,    0,
  400,  266,  267,  260,  262,  264,  263,  261,  255,  268,
  259,  257,  258,  265,  443,  445,  446,  466,  471,  470,
  465,  464,  463,  447,  452,    0,  451,    0,  440,  468,
  469,  438,  444,  462,  442,  467,  441,  507,    0,  675,
  650,  725,    0,  717,    0,    0,  322,    0,  333,  334,
  330,  336,  332,  331,  339,  338,  335,  337,  329,  328,
  475,    0,  272,    0,  289,  286,  285,  205,  169,  165,
  203,  167,  214,    0,  213,    0,  201,  195,  206,  207,
  198,  162,  202,  208,  166,  204,  196,  197,  168,  209,
  174,  190,  191,  175,  176,  177,  178,  185,  179,  193,
  194,  188,  192,  181,  186,  182,  187,  180,  184,  183,
  189,    0,  173,  200,  164,  199,  373,    0,  398,    0,
    0,  449,    0,  459,  460,  457,  458,  456,  461,  455,
  508,  726,  718,  326,  323,  476,  273,    0,  211,    0,
  226,  224,  233,  223,  218,  227,  231,  220,  228,  230,
  234,  225,  219,  232,  229,  221,  222,  217,  171,    0,
  374,  399,  453,  450,  215,  212,  172,
};
static const short yydgoto[] = {                          1,
  981,  982, 1155, 1156,   24,   25,   26,   27,   28,   29,
   30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
   40,   41,   42,   43,   44,   45,  306,  307,  308,  309,
   53,  402,  403,  404,  405,  406,  344,  345,  346,  347,
  348,  349,  350,  351,  352,  353,  354,  355,  356,  357,
   73,   74,   75,   76,   77,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,  300,  301,  302,  311,
   63,  903,  312,  904,  905,  906,  907,  908,  909,  910,
  911,  912,  913,  914,  915,  916,  917,  918,  919,  920,
  921,  922,  923,  924,  925,  926,  927,  928, 1243, 1552,
 1553, 1228, 1514, 1515, 1598, 1578, 1516,  124,   50,  672,
  125,  673,  674,  675,  676,  677,  678,  679,  680,  681,
  682,  683,  684,  685,  686,   60,  555,  556,  850, 1376,
 1377,  557,  558,  559,  560, 1199, 1382, 1200,   58,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  829,
 1354, 1355, 1500, 1486, 1356,   64,  586,  587,  588,  589,
  590,   67,  619,  620,  621,  622,  623,  958, 1425, 1426,
   68,  627,  628,  629,  630,  964, 1440, 1441,  127,   51,
  707,  128,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,  719,  720,  721,  722,  723,  724,  725,
  726,  727, 1024, 1466, 1467, 1570, 1561, 1468,   59,  545,
  546,  845, 1371, 1372,  547,  548,  549,   52,  394,  395,
  396,  397,  134,  135,  136,  137,   55,  415,  416,  743,
 1327, 1328,  417,  418,  419,  205,  206,  207,  208,  209,
  210,  211,  212,  213,  214,  215,  216,  217,  218,  219,
  220,  221,  222,  223,  224,  225,  226,  227,  228,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
  250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  461, 1133, 1134,  459, 1109, 1110,   57,  494,
  495,  496,  497,  498,  499,  500,  501,  818, 1344, 1345,
  815, 1338, 1339,  100,  101,  102,  103,  104,  105,  106,
  107,  108,  109,  110,  111,  112,  113,  114,  115,  116,
  117,  118,  119,  120,  121,  122,  322,  323,  324,  325,
  326,  327,  328,  329,  330,
};
static const short yysindex[] = {                         0,
  804,  -25,  -98,  -87,    0,    0,    0,    0,  -80,    0,
  -78,    0,    0,    0,    0,  -69,  -59,    0,    0,  -48,
  -38,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -229,  703, -354,
 -322,  -21,  -18, -224,  -13,  407,  -11,   -9,   -6,    8,
  666, -247, -283,   25,  254,  175,   38,   54,   92,   98,
  118,  120, -117,    0,    0,    0,    0,    0,  122,  127,
  131,  132,  136,  140,  141,  142,  146,  148,  150,  151,
  152,  155,  156,  161,  162,  168,  172,  179,  180,  137,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  128,    0,    0,  129,    0, -238, -225,
    0,  182,  184, -106,    0,    0,    0, -227,    0,  189,
  193,  204,  205,  216,  217,  226,  229,  230,  234,  236,
  237,  241,  242,  248,  258,  260,  265,  266,  288,  289,
  292,  293,  296,  297,  311,  313,  316,  317,  319,  320,
  321,  323,  324,  327,  330,  333,  339,  341,    0,  343,
    0,  346,  349,  355,  358,  359,  360,  362,  363,  365,
  366,  367,  368,  374,  375,  376,  377,  379,  381,  385,
  395,  396,  397,  400, -121,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, -236,  741, -251, -221,  220,  401,  404,  405,  406,
  408,  409,  410,  411,  412,  415,  416,  417,  -10,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  221,  420,  421, -111,    0,    0,    0,    0,
  274,    0, -233,    0,  422,  423,  424,  425,  427,  429,
  430,  364,    0,    0,    0,    0,    0,    0,    0,    0,
  433,  434,  435,  436,  441,  442,  443,  446,  450,  451,
  452,  453,  456,  -65,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -245, -218,    0,
   47,   99,  100,  460,    0,   57,   58,  130,  143,   60,
   61,  147,  147,  154,  157,   62,   69,  158,  147,   70,
   73,   74,   81,   85,   88,   96,  503,    0,  812,  336,
    0,  504,  505, -101,    0,    0,    0,  508,  510,  511,
  513,  -85,    0,    0,    0,    0,  159,  160,  517,    0,
    0,  518,  521,    0,  -86,    0,    0,    0,    0,  113,
  147,  119,  121,  147,  164,  170,  173,  124,  125,  185,
  177,  206,  138,  144,  149,  214,  181,  153,  223,  224,
  227,  165,  147,  166,  167,  235,  215,  174,  243,  244,
  147,  249,  225,  250,  252,  186,  187,  191,  566,  194,
  574,  147,  147,  199,  147,  247,  255,  200,  208,  210,
 -404, -377,  222,  232,  147,  147,  281,  147,  282,  233,
  246,  251,  253,  257,  581,    0,    0,    0,  621,  627,
    0,  634,  638, -104,    0,    0,    0,    0,    0,    0,
    0,  626,  652,  658,  659,  663,  667,    0,  670,  675,
  677,  678,  679,  680,  683,  684,  685,  688,  689,  690,
  219,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  691,    0,  692, -119,    0,    0,    0,    0,  668,
    0,  694,  696,  700, -112,    0,    0,    0,    0,    0,
    0,  344,  347,  348,  350,  352,  353,  357,  361,  -41,
  369,  370,  299,  717,    0,    0,  371,  372,  720,    0,
  516,  721,  701,  724,  733,  -56,    0,    0,    0,    0,
  331,  335,  338,  380,  340,  342,  147,  736,    0,    0,
  383,  354,  388,  391,  394,  402,  418,  419,  426,  428,
  431,  444,  747,    0,  759,  761,    0,  764, -109,    0,
    0,    0,    0,  768,  767,    0, -122,    0,    0,    0,
  771,  772,  773,    0,  774,  777,  778,  779,  782,  783,
 -321,  784,  786,  791,  792,  795,  796,  807,  813,  815,
  818,  819,  824,  833,  835,  836,    0,  837,  841,  843,
  844,  847,  848,  849,  850,  851,  852,  853,  854,  855,
  858,  169,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  838,  860,  866,  867,
  869,  871,  872,  874,  876,  880,    0,  881,  883,  886,
  887,  888,  890,  891,  893,  894,   95,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  464,  477,  902,
    0,    0,  147,  541,  543,  907,    0,  909,  910,    0,
  551,  552,  913,  911,    0,  916,  918,  922,  924,  925,
  926,  935,  936,  939,  942,  943,  944,  945,  947,  949,
  950,  953,  954,  958,  959,  960,  965,  966,  967,  968,
  969,  970,  971,  977,  978,  979,  980,  981,  982,  983,
  984,  985,  986,  988,  788,  990,  826,  992,  999, 1002,
 1008, 1010, 1011, 1013, 1017, 1018, 1019, 1023, 1025, 1027,
 1028, 1029, 1030, 1033, -223, 1034, 1039, 1041, 1042, 1045,
 1046, 1047, 1048,    0, 1050,  147,  643, 1051,  695,  697,
 1058,    0,    0,  644,  702,  705,  656,  664, 1063,  665,
  671,  673,  676,  681,  682,  710,  527,  722,  723,  686,
  727, 1086,    0,  728, 1089,  731, 1095,    0,    0, 1096,
  737,  739,  763, 1103,    0, 1104, 1105, 1110, 1112, 1114,
 1115, 1116, 1117, 1119, 1120, 1121, 1122, 1123, 1124, 1125,
 1130, 1132, 1134,    0, 1135, 1136,    0, 1137, 1140, 1141,
 1142, 1143, 1144,    0, 1145, 1147, 1148, 1149, 1150, 1153,
 1154, 1155, 1156, 1157, 1159, 1160, 1161, 1164,    0, 1168,
 1171, 1172,  -12,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  814,
  816,  817, 1139,    0, 1175, 1177, 1180, 1183, 1184, 1185,
 1186,    0, 1187, 1188, 1189, 1190, 1193, 1194, 1195, 1196,
 1206, 1209, 1215, 1216,    0,    0,  856, 1217,  859, 1220,
    0,    0,  861, 1222, 1225,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  147,  147,  147,  147,  147,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  895,  897,
  147,  898,  905,  908,  914,  892,  917,  919,  147,  147,
  281, 1226,    0,    0,  899, -358,  827,  900,  901,  865,
  868,  879,  920, 1255,  929,  930,  932,  933,  921,  934,
  937,  896,  938, 1259,    0, 1264, 1272,    0, 1275, 1297,
 1298,    0,    0,    0, 1301, 1309,  946,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   -3,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   -2,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  281,  281,  281,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -249, 1310, 1312, -240, 1315, 1316,
    0, 1317, 1318, 1319, 1320, 1321,  884, 1322, 1323, 1324,
 1325, 1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333,    0,
 1334,  972, 1335,    0, -326, 1336, 1337,  927, 1355,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  940,  987,  989,  941,  948, 1339,  951,  952,
  955,  956,  957,  991,  961,  962,  993,  963,  964,  973,
  994,  974, 1340,  975,  997,  976, 1343,    0, 1344, 1345,
 1348,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1350,  218, 1352,    0, 1360,  373,    0,    0,    0,
    0,    0,    0, 1364, 1365, 1366, 1371, 1372, 1373, 1374,
 1375, 1376, 1377, 1378, 1383, 1384,    0, 1385, 1386, 1387,
 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1057, 1396, 1397,
 1398, 1399, 1400, 1401, 1402, 1403, 1404,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    6,    0,    0,  788,
    0,  826,    0,    0,    0,    0,    0,    9,    0,    0,
    0,    0,    0,   15,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   19,    0,  624,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   22,    0,    0,    0,    0,   28,    0,    0,    0, 1066,
  763, 1406, 1407, 1408, 1409, 1410, 1411, 1074, 1413, 1414,
 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424,
 1425, 1426,  864, 1427, 1428, 1429,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   36,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   39,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   42,    0, -255,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  946,    0,
    0,    0, -249,    0, -240,  624,    0,  884,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  972,    0, -326,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   48,    0,  549,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   50,    0,    0,    0,    0,    0,  218,    0,  373,
 -255,    0, 1057,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  549,    0, 1074,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  864,
    0,    0,    0,    0,    0,    0,    0,
};
static const short yyrindex[] = {                         0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1367,
 1368,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1369,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1430,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1434,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1430, 1430, 1430, 1430, 1430,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1434, 1434, 1434,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  781,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   52, 1435,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -237,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  623,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  781,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, -237,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  623,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,
};
static const short yygindex[] = {                         0,
 -372, -614, -475,-1029,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1191,    0,    0,
    0,    0, 1093,    0,    0,    0,    0, 1152,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1431,    0,    0,    0,    0, 1210,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  595,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 -100,    0,    0,  -79,  -76,    0,    0,    0,    0,    0,
    0,  831,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    1,  995,    0,    0,    0,    0,    0,  126,    0,    0,
  996,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   18,   23,    0,    0,    0,    0,  928,    0,    0,
    0,    0,    0,  889,    0,    0,    0,    0,    0,  -47,
    0,    0,  885,    0,    0,    0,    0,  -50,    0,    0,
    0,    0,  806,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  -45,  -46,    0,    0,    0,    0,
    0,    0,    0,   14,  998,    0,    0,    0,    0, 1126,
    0,    0,    0, 1395,    0,    0,    0,    0,    0,    0,
    0,   40, 1106,    0,    0,    0, 1341,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  190,    0,    0,  195,    0,    0,
 1032,    0,    0,    0,    0,    0,    0,    0,    0,   43,
    0,    0,   41,    0, 1432,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1201,    0,    0,
    0,    0,    0,    0,    0,
};
#define YYTABLESIZE 1550
static const short yytable[] = {                        642,
  643,  806,  965,  485,  541,  847,  649,  364,  303, 1564,
  615, 1565,  854,  579, 1374,  960, 1336,  391,  409,  487,
  821,  488,  582,  730,   48, 1342,   69,  454,  411,  454,
  398,  131, 1566,   46,  550,   49, 1567,  624,  744,  736,
 1330, 1332,   54,  583,   56, 1152, 1153, 1154,  747, 1479,
  454,  750, 1483,   61,  454, 1329, 1331,  132, 1485,  613,
  797,  798, 1488,   62, 1478, 1502,  123, 1482,  933,   70,
  769, 1504,  489, 1484,   65,  490,  641, 1487,  777, 1558,
 1501,   71, 1560,  399,   66, 1563, 1503,  799,  800,  788,
  789, 1580,  791, 1600, 1557,  288,  551, 1559,  126,   47,
 1562,  129,  803,  804,  130,  807, 1579, 1568, 1599,  138,
  288,  272, 1247,  273,  574,  392,  274,  976,  977,  978,
  979,  980, 1333, 1334, 1335,  454,  552, 1299, 1300,  133,
  275,  491,  553,  624,  139,  304,  541,  310,   69,  616,
  140,  141,  142,  550,  303,  143,  615,  313,  492,  131,
  360,  487,  144,  488,  391,   72,  584,  412,  361,  400,
  358,  145,  146,  147,  148,  149,  625,  150,  305,  411,
  398,  542,  151,  152,  805,  132,  359, 1375,  362,  153,
  363,   70,  366,  154,  393,  155,  156,  367,  157,  585,
  331,  368,  369,   71,  158,  413,  370,  401,  554,  582,
  371,  372,  373,  543,  489,  551,  374,  490,  375,  617,
  376,  377,  378,  159,  160,  379,  380, 1337,  161, 1034,
  583,  381,  382,  399,  941,  162, 1343,  414,  383,  163,
  164,  165,  384,  332,  166,  552,  626,  167,  168,  385,
  386,  553,  407,  878,  408,  276,  879,  133,  169,  420,
  389,  390,  392,  421,  170,  171, 1569,  172,  173,  174,
  175,  387,  625,  491,  422,  423,  544,   72,  880,  881,
  176,  304,  618,  177,  454,  616,  424,  425,  561,  576,
  492,  493,  178,  333,  179,  180,  426,  882,  181,  427,
  428,  182,  183, 1012,  429,  184,  430,  431,  412,  400,
  883,  432,  433,  542,  305,  884,  185,  554,  434,  277,
  278,  279,  280,  281,  282,  283,  284,  885,  435,  334,
  436,  393,  335,  336,  886,  437,  438,  186,  187,  887,
  188,  888,  626,  584,  189,  543,  413,  401,  190,  191,
  192,  193,  194,  842,  889,  617,  195,  196,  439,  440,
  687,  688,  441,  442,  689,  197,  443,  444,  285,  690,
 1039, 1279, 1280, 1281, 1282, 1283,  585,  337,  414,  338,
  339,  445,  890,  446,  691,  692,  447,  448,  891,  449,
  450,  451,  693,  452,  453,  340,  694,  454,  198,  199,
  455,  200,   78,  456,  286,  892,  581,  201,  544,  457,
  202,  458,  893,  460,   79,  203,  462,  695,  618,  463,
  204,  696,  697,  493,  894,  464,  895,  896,  465,  466,
  467,  897,  468,  469,  658,  470,  471,  472,  473,   80,
  331,  341,   81,   82,  474,  475,  476,  477,   83,  478,
   84,  479,  698, 1166,  699,  480,  659,  660,  864,  865,
  866,  867,  868,  869,  870,  481,  482,  483,  700,  661,
  484,  562,  342,  343,  563,  564,  565,  631,  566,  567,
  568,  569,  570,  332,  502,  571,  572,  573,  287,  701,
  577,  578,  591,  592,  593,  594,  898,  595,  598,  596,
  597,  600,  899,  503,  601,  602,  603,   85,   86,  504,
  505,  604,  605,  606,  900,  901,  607,   87,   88,  314,
  608,  609,  610,  611,  702,  288,  612,  902,  634,  632,
  633,  635,  636,  333,  639,  640,  646,  637,  703,   89,
   90,  506,  507,  647,  650, 1296,  508,  651,  652,  704,
  638,  662,  663,  664,  641,  653,  665,   91,   92,  654,
  509,  644,  655,  666,  645,  648,  315,  510,   93,  334,
  656,  657,  335,  336,  728,  729,  732,   94,  667,  668,
  733,  734,  316,  735, 1412,  740,  511,  746,  741,  738,
  739,  742,  756,  748,  751,  749,  669,  670,  754,  755,
  752,  687,  688,  753,  317,  689,  318,  757,  319,  320,
  690,  763,  759,  758,  512,  513,  705,  337,  760,  338,
  339,  762,  671,  761,  514,  691,  692,  764,  321,  314,
  765,  766,  706,  693,  767,  340,  785,  694, 1286,  768,
  770,  771,  772,  515,  787,  773, 1294, 1295,  774,  814,
  775,  776,  516,  517, 1413,  779,  778,  780,  695,  781,
  782,  783,  696,  697, 1414,  784,   95,   96,  786,   97,
   98,   99,  139,  790,  794, 1415,  315,  792,  140,  141,
  142,  341,  795,  143,  796,  793,  518,  519,  805,  808,
  144,  816,  316,  698,  823,  699,  801,  817, 1416,  145,
  146,  147,  148,  149,  819,  150,  802,  809,  820,  700,
  151,  152,  342,  343,  317, 1417,  318,  153,  319,  320,
  810,  154,  824,  155,  156,  811,  157,  812,  825,  826,
  701,  813,  158,  827, 1418, 1419,  849,  828,  321, 1429,
  830, 1420, 1421, 1422, 1423,  831,  520,  832,  833,  834,
  835,  159,  160,  836,  837,  838,  161, 1424,  839,  840,
  841,  844,  846,  162,  851,  702,  852,  163,  164,  165,
  853,  930,  166,  873,  856,  167,  168,  857,  858,  703,
  859,  878,  860,  861,  879,  874,  169,  862,  877,  929,
  704,  863,  170,  171,  931,  172,  173,  174,  175,  871,
  872,  875,  876,  932,  942,  935,  880,  881,  176,  936,
  938,  177,  937,  943,  939,  955,  940, 1581,  945, 1430,
  178,  946,  179,  180,  947,  882,  181,  956,  944,  182,
  183,  957,  948,  184,  959,  952,  962,  963,  883,  967,
  968,  969,  970,  884,  185,  971,  972,  973,  949,  950,
  974,  975,  983, 1431,  984,  885,  951,  705, 1582,  985,
  986,  953,  886,  987,  988,  186,  187,  887,  188,  888,
 1432, 1583,  189,  706,  954,  989,  190,  191,  192,  193,
  194,  990,  889,  991,  195,  196,  992,  993, 1584, 1433,
 1434,  216,  994,  197, 1036, 1585, 1435, 1436, 1437, 1438,
 1586,  995, 1587,  996,  997,  998, 1014, 1037, 1489, 1490,
  890,  999, 1439, 1000, 1001, 1588,  891, 1002, 1003, 1004,
 1005, 1006, 1007, 1008, 1009, 1010,  198,  199, 1011,  200,
 1015,  276,  216,  892, 1185,  201, 1016, 1017,  202, 1018,
  893, 1019, 1020,  203, 1021,  216, 1022, 1491,  204, 1589,
 1023, 1025,  894, 1026,  895,  896, 1027, 1028, 1029,  897,
 1030, 1031,  216, 1032, 1033, 1492, 1590, 1591,   78,  216,
 1038, 1040, 1493, 1041,  216, 1042,  216, 1043, 1044, 1048,
   79, 1045, 1046, 1047, 1049, 1592, 1050, 1593, 1594,  216,
 1051, 1494, 1052, 1053, 1054,  277,  278,  279,  280,  281,
  282,  283,  284, 1055, 1056,   80,  502, 1057,   81,   82,
 1058, 1059, 1060, 1061,   83, 1062,   84, 1063, 1064, 1495,
 1496, 1065, 1066,  216,  898,  503, 1067, 1068, 1069, 1497,
  899,  504,  505, 1070, 1071, 1072, 1073, 1074, 1075, 1076,
  216,  216,  900,  901,  285, 1077, 1078, 1079, 1080, 1081,
 1082, 1083, 1084, 1085, 1086,  902, 1087, 1595, 1111,  216,
 1135,  216,  216,  506,  507,  327,  327, 1136,  508,    2,
 1137, 1498,    3,   85,   86, 1596, 1138,  658, 1139, 1140,
  286, 1141,  509,   87,   88, 1142, 1143, 1144, 1597,  510,
    4, 1145, 1499, 1146,    5, 1147, 1148, 1149, 1150,  659,
  660, 1151, 1157,    6,  327,   89,   90, 1158,  511, 1159,
 1160,    7,  661, 1161, 1162, 1163, 1164, 1167, 1172,    8,
 1165, 1168,  327,   91,   92, 1169, 1171, 1170,    9,  327,
 1175,  216, 1173, 1177,   93, 1174,  512,  513, 1176, 1178,
 1184,   10,   11,   94,   12, 1179,  514, 1180,  327,  216,
 1181,   13, 1186, 1187, 1190, 1182, 1183, 1189, 1191, 1192,
 1188, 1193,  216, 1194,  287,  515, 1195, 1196,   14, 1197,
 1198, 1201, 1202, 1203,  516,  517,  327,  327, 1204,   15,
 1205,   16, 1206, 1207, 1208, 1209,  327, 1210, 1211, 1212,
 1213, 1214, 1215, 1216,  662,  663,  664,   17, 1217,  665,
 1218,  288, 1219, 1220, 1221, 1222,  666, 1252,  518,  519,
 1223, 1224, 1225, 1226, 1227, 1229,   18, 1230, 1231, 1232,
 1233,  667,  668, 1234, 1235, 1236, 1237, 1238,  327, 1239,
 1240, 1241,   95,   96, 1242,   97,   98,   99, 1244,  669,
  670, 1245, 1246, 1253, 1249, 1254, 1250, 1251, 1255,  327,
   19, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263,   20,
   21, 1264, 1265, 1266, 1267,  671,   22,   23,  520, 1088,
 1089, 1090, 1091, 1092, 1268, 1093, 1094, 1269, 1095, 1096,
 1097, 1098, 1099, 1270, 1271, 1100, 1272, 1273, 1275, 1274,
 1353, 1276, 1277, 1278, 1297, 1101, 1102, 1103, 1104, 1105,
 1106, 1301, 1284, 1107, 1285, 1287, 1108, 1112, 1113, 1114,
 1115, 1116, 1288, 1117, 1118, 1289, 1119, 1120, 1121, 1122,
 1123, 1290, 1291, 1124, 1292, 1308, 1293, 1318, 1313, 1298,
 1302, 1303, 1319, 1125, 1126, 1127, 1128, 1129, 1130, 1304,
 1320, 1131, 1305, 1321, 1132, 1531, 1532, 1533, 1534, 1535,
 1307, 1536, 1537, 1306, 1538, 1539, 1540, 1541, 1542, 1309,
 1310, 1543, 1311, 1312, 1314, 1322, 1323, 1315, 1317, 1324,
 1316, 1544, 1545, 1546, 1547, 1548, 1549, 1325, 1340, 1550,
 1341, 1326, 1551, 1346, 1347, 1348, 1349, 1350, 1351, 1352,
 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365, 1366,
 1367, 1368, 1369, 1373, 1378, 1379, 1380, 1370, 1381, 1388,
 1403, 1407, 1408, 1409, 1383, 1386, 1410, 1384, 1411, 1385,
 1427, 1394, 1387, 1397, 1401, 1389, 1390, 1405, 1428, 1391,
 1392, 1393, 1442, 1443, 1444, 1395, 1396, 1398, 1399, 1445,
 1446, 1447, 1448, 1449, 1450, 1451, 1452, 1400, 1402, 1404,
 1406, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461,
 1462, 1463, 1464, 1465, 1469, 1470, 1471, 1472, 1473, 1474,
 1475, 1476, 1477, 1505, 1507, 1508, 1509, 1510, 1511, 1512,
 1513, 1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525,
 1526, 1527, 1528, 1529, 1530, 1554, 1555, 1556,   26,  237,
  414,  133,   34,  284,  737,  614,  580, 1248,  575, 1607,
 1606, 1605, 1013,  365, 1577, 1575, 1506,  961, 1574, 1602,
 1601,  966, 1035,  934, 1603, 1576,  843, 1604, 1571,  731,
  745, 1481,  599, 1572, 1480,  822,    0, 1573,  410,    0,
    0,  388,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  848,    0,    0,  486,    0,    0,    0,  855,
};
static const short yycheck[] = {                        372,
  373,  477,  125,  125,  256,  125,  379,  125,  256,  265,
  256,  267,  125,  125,  341,  125,  266,  256,  125,  256,
  125,  258,  256,  125,  123,  266,  256,  265,  256,  267,
  256,  256,  288,   59,  256,  123,  292,  256,  125,  125,
   44,   44,  123,  277,  123,  269,  270,  271,  421,   44,
  288,  424,   44,  123,  292,   59,   59,  282,   44,  125,
  465,  466,   44,  123,   59,   44,  421,   59,  125,  299,
  443,   44,  309,   59,  123,  312,  398,   59,  451,   44,
   59,  311,   44,  309,  123,   44,   59,  465,  466,  462,
  463,   44,  465,   44,   59,   44,  318,   59,  421,  125,
   59,  123,  475,  476,  123,  478,   59,  363,   59,  123,
   59,  123,  125,  123,  125,  354,  123,  439,  440,  441,
  442,  443, 1152, 1153, 1154,  363,  348,  486,  487,  354,
  123,  368,  354,  256,  256,  383,  256,  421,  256,  385,
  262,  263,  264,  256,  256,  267,  256,  123,  385,  256,
   59,  256,  274,  258,  256,  385,  390,  385,   61,  385,
  123,  283,  284,  285,  286,  287,  385,  289,  416,  256,
  256,  423,  294,  295,  398,  282,  123,  504,   61,  301,
   61,  299,   61,  305,  423,  307,  308,   61,  310,  423,
  256,   61,   61,  311,  316,  423,   61,  423,  420,  256,
   61,   61,   61,  455,  309,  318,   61,  312,   61,  455,
   61,   61,   61,  335,  336,   61,   61,  467,  340,  125,
  277,   61,   61,  309,  597,  347,  467,  455,   61,  351,
  352,  353,   61,  299,  356,  348,  455,  359,  360,   61,
   61,  354,   61,  256,   61,  256,  259,  354,  370,   61,
  123,  123,  354,   61,  376,  377,  512,  379,  380,  381,
  382,  125,  385,  368,   61,   61,  518,  385,  281,  282,
  392,  383,  518,  395,  512,  385,   61,   61,   59,   59,
  385,  518,  404,  349,  406,  407,   61,  300,  410,   61,
   61,  413,  414,  125,   61,  417,   61,   61,  385,  385,
  313,   61,   61,  423,  416,  318,  428,  420,   61,  320,
  321,  322,  323,  324,  325,  326,  327,  330,   61,  385,
   61,  423,  388,  389,  337,   61,   61,  449,  450,  342,
  452,  344,  455,  390,  456,  455,  423,  423,  460,  461,
  462,  463,  464,  125,  357,  455,  468,  469,   61,   61,
  256,  257,   61,   61,  260,  477,   61,   61,  369,  265,
  733,  976,  977,  978,  979,  980,  423,  433,  455,  435,
  436,   61,  385,   61,  280,  281,   61,   61,  391,   61,
   61,   61,  288,   61,   61,  451,  292,   61,  510,  511,
   61,  513,  256,   61,  405,  408,  123,  519,  518,   61,
  522,   61,  415,   61,  268,  527,   61,  313,  518,   61,
  532,  317,  318,  518,  427,   61,  429,  430,   61,   61,
   61,  434,   61,   61,  256,   61,   61,   61,   61,  293,
  256,  497,  296,  297,   61,   61,   61,   61,  302,   61,
  304,   61,  348,  816,  350,   61,  278,  279,  490,  491,
  492,  493,  494,  495,  496,   61,   61,   61,  364,  291,
   61,   61,  528,  529,   61,   61,   61,  421,   61,   61,
   61,   61,   61,  299,  256,   61,   61,   61,  489,  385,
   61,   61,   61,   61,   61,   61,  499,   61,  125,   61,
   61,   59,  505,  275,   61,   61,   61,  361,  362,  281,
  282,   61,   61,   61,  517,  518,   61,  371,  372,  256,
   61,   61,   61,   61,  420,  526,   61,  530,   59,  421,
  421,  465,  465,  349,  465,  465,  465,  398,  434,  393,
  394,  313,  314,  465,  465, 1011,  318,  465,  465,  445,
  398,  373,  374,  375,  398,  465,  378,  411,  412,  465,
  332,  398,  465,  385,  398,  398,  303,  339,  422,  385,
  465,   59,  388,  389,   61,   61,   59,  431,  400,  401,
   61,   61,  319,   61,  357,   59,  358,  465,   61,  421,
  421,   61,  398,  465,  421,  465,  418,  419,  465,  465,
  421,  256,  257,  421,  341,  260,  343,  421,  345,  346,
  265,  421,  465,  398,  386,  387,  512,  433,  465,  435,
  436,  398,  444,  465,  396,  280,  281,  465,  365,  256,
  398,  398,  528,  288,  398,  451,   61,  292, 1001,  465,
  465,  465,  398,  415,   61,  421, 1009, 1010,  465,   59,
  398,  398,  424,  425,  427,  421,  398,  398,  313,  398,
  465,  465,  317,  318,  437,  465,  520,  521,  465,  523,
  524,  525,  256,  465,  465,  448,  303,  421,  262,  263,
  264,  497,  465,  267,  465,  421,  458,  459,  398,  398,
  274,   61,  319,  348,   59,  350,  465,   61,  471,  283,
  284,  285,  286,  287,   61,  289,  465,  465,   61,  364,
  294,  295,  528,  529,  341,  488,  343,  301,  345,  346,
  465,  305,   61,  307,  308,  465,  310,  465,   61,   61,
  385,  465,  316,   61,  507,  508,   59,   61,  365,  357,
   61,  514,  515,  516,  517,   61,  518,   61,   61,   61,
   61,  335,  336,   61,   61,   61,  340,  530,   61,   61,
   61,   61,   61,  347,   61,  420,   61,  351,  352,  353,
   61,   61,  356,  465,  421,  359,  360,  421,  421,  434,
  421,  256,  421,  421,  259,   59,  370,  421,   59,   59,
  445,  421,  376,  377,   61,  379,  380,  381,  382,  421,
  421,  421,  421,   61,   59,  465,  281,  282,  392,  465,
  421,  395,  465,  421,  465,   59,  465,  259,  421,  437,
  404,  421,  406,  407,  421,  300,  410,   59,  465,  413,
  414,   61,  421,  417,   61,  398,   59,   61,  313,   59,
   59,   59,   59,  318,  428,   59,   59,   59,  421,  421,
   59,   59,   59,  471,   59,  330,  421,  512,  300,   59,
   59,  421,  337,   59,   59,  449,  450,  342,  452,  344,
  488,  313,  456,  528,  421,   59,  460,  461,  462,  463,
  464,   59,  357,   59,  468,  469,   59,   59,  330,  507,
  508,  259,   59,  477,  421,  337,  514,  515,  516,  517,
  342,   59,  344,   59,   59,   59,   59,  421,  275,  276,
  385,   61,  530,   61,   61,  357,  391,   61,   61,   61,
   61,   61,   61,   61,   61,   61,  510,  511,   61,  513,
   61,  256,  300,  408,  398,  519,   61,   61,  522,   61,
  415,   61,   61,  527,   61,  313,   61,  314,  532,  391,
   61,   61,  427,   61,  429,  430,   61,   61,   61,  434,
   61,   61,  330,   61,   61,  332,  408,  409,  256,  337,
   59,  421,  339,  421,  342,   59,  344,   59,   59,   59,
  268,  421,  421,   61,   59,  427,   59,  429,  430,  357,
   59,  358,   59,   59,   59,  320,  321,  322,  323,  324,
  325,  326,  327,   59,   59,  293,  256,   59,  296,  297,
   59,   59,   59,   59,  302,   59,  304,   59,   59,  386,
  387,   59,   59,  391,  499,  275,   59,   59,   59,  396,
  505,  281,  282,   59,   59,   59,   59,   59,   59,   59,
  408,  409,  517,  518,  369,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,  530,   59,  499,   59,  427,
   59,  429,  430,  313,  314,  275,  276,   59,  318,  256,
   59,  438,  259,  361,  362,  517,   59,  256,   59,   59,
  405,   59,  332,  371,  372,   59,   59,   59,  530,  339,
  277,   59,  459,   59,  281,   59,   59,   59,   59,  278,
  279,   59,   59,  290,  314,  393,  394,   59,  358,   59,
   59,  298,  291,   59,   59,   59,   59,  465,  465,  306,
   61,   61,  332,  411,  412,  421,   59,  421,  315,  339,
  465,  499,  421,   61,  422,  421,  386,  387,  465,  465,
  421,  328,  329,  431,  331,  465,  396,  465,  358,  517,
  465,  338,  421,  421,   59,  465,  465,  421,  421,   61,
  465,  421,  530,   59,  489,  415,   61,  421,  355,  421,
  398,   59,   59,   59,  424,  425,  386,  387,   59,  366,
   59,  368,   59,   59,   59,   59,  396,   59,   59,   59,
   59,   59,   59,   59,  373,  374,  375,  384,   59,  378,
   59,  526,   59,   59,   59,   59,  385,   59,  458,  459,
   61,   61,   61,   61,   61,   61,  403,   61,   61,   61,
   61,  400,  401,   61,   61,   61,   61,   61,  438,   61,
   61,   61,  520,  521,   61,  523,  524,  525,   61,  418,
  419,   61,   61,   59,  421,   59,  421,  421,   59,  459,
  437,   59,   59,   59,   59,   59,   59,   59,   59,  446,
  447,   59,   59,   59,   59,  444,  453,  454,  518,  472,
  473,  474,  475,  476,   59,  478,  479,   59,  481,  482,
  483,  484,  485,   59,   59,  488,  421,   61,   59,  421,
  397,  421,   61,   59,   59,  498,  499,  500,  501,  502,
  503,  465,  398,  506,  398,  398,  509,  472,  473,  474,
  475,  476,  398,  478,  479,  398,  481,  482,  483,  484,
  485,  398,  421,  488,  398,   61,  398,   59,  398,  421,
  421,  421,   59,  498,  499,  500,  501,  502,  503,  465,
   59,  506,  465,   59,  509,  472,  473,  474,  475,  476,
  421,  478,  479,  465,  481,  482,  483,  484,  485,  421,
  421,  488,  421,  421,  421,   59,   59,  421,  421,   59,
  465,  498,  499,  500,  501,  502,  503,   59,   59,  506,
   59,  426,  509,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,  470,  426,   44,   61,
   61,   59,   59,   59,  465,  465,   59,  421,   59,  421,
   59,  421,  465,  421,  421,  465,  465,  421,   59,  465,
  465,  465,   59,   59,   59,  465,  465,  465,  465,   59,
   59,   59,   59,   59,   59,   59,   59,  465,  465,  465,
  465,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,  397,   59,   59,   59,   59,   59,   59,
   59,   59,   59,  398,   59,   59,   59,   59,   59,   59,
  397,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,   59,   59,   59,  123,
  123,  123,   59,   59,  402,  344,  306,  903,  289, 1600,
 1580, 1578,  672,   73, 1504, 1488, 1381,  619, 1486, 1560,
 1558,  627,  707,  586, 1561, 1502,  521, 1563, 1479,  394,
  415, 1332,  322, 1483, 1330,  494,   -1, 1485,  134,   -1,
   -1,  100,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  545,   -1,   -1,  205,   -1,   -1,   -1,  555,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 532
#if YYDEBUG
static const char *yyname[] = {

"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,"','",0,0,0,0,0,0,0,0,0,0,0,0,0,0,"';'",0,"'='",0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
"ACCEPT_PASSWORD","ACTION","ADMIN","AFTYPE","T_ALLOW","ANTI_NICK_FLOOD",
"ANTI_SPAM_EXIT_MESSAGE_TIME","ANTI_SPAM_CONNECT_NUMERIC","AUTOCONN","T_BLOCK",
"BURST_AWAY","BURST_TOPICWHO","BYTES","KBYTES","MBYTES","GBYTES","TBYTES",
"CALLER_ID_WAIT","CAN_FLOOD","CAN_IDLE","CHANNEL","CIDR_BITLEN_IPV4",
"CIDR_BITLEN_IPV6","CIPHER_PREFERENCE","CLASS","CLIENTCERT_HASH","CLOAK_KEY1",
"CLOAK_KEY2","CLOAK_KEY3","CLOAK_WHOIS_ACTUALLY","ACCOUNT_WHOIS","COMPRESSED",
"COMPRESSION_LEVEL","CONNECT","CONNECTFREQ","CRYPTLINK","CYCLE_ON_HOSTCHANGE",
"DEFAULT_CIPHER_PREFERENCE","DEFAULT_FLOODCOUNT","DEFAULT_SPLIT_SERVER_COUNT",
"DEFAULT_SPLIT_USER_COUNT","DENY","DESCRIPTION","DIE","DISABLE_AUTH",
"DISABLE_FAKE_CHANNELS","DISABLE_HIDDEN","DISABLE_LOCAL_CHANNELS",
"DISABLE_REMOTE_COMMANDS","DNSBL","DOT_IN_IP6_ADDR","DOTS_IN_IDENT","DURATION",
"EGDPOOL_PATH","EMAIL","ENABLE","ENCRYPTED","EXCEED_LIMIT","EXEMPT",
"FAILED_OPER_NOTICE","FAKENAME","IRCD_FLAGS","FLATTEN_LINKS","FFAILED_OPERLOG",
"FKILLLOG","FKLINELOG","FGLINELOG","FIOERRLOG","FOPERLOG","FOPERSPYLOG",
"FUSERLOG","GECOS","GENERAL","GLINE","GLINES","GLINE_EXEMPT","GLINE_LOG",
"GLINE_TIME","GLINE_MIN_CIDR","GLINE_MIN_CIDR6","GLOBAL_KILL","IRCD_AUTH",
"NEED_IDENT","HAVENT_READ_CONF","HIDDEN","HIDDEN_ADMIN","HIDDEN_NAME",
"HIDDEN_OPER","HIDE_SERVER_IPS","HIDE_SERVERS","HIDE_SPOOF_IPS","HOST","HUB",
"HUB_MASK","IDLETIME","IGNORE_BOGUS_TS","INVISIBLE_ON_CONNECT","IP","KILL",
"KILL_CHASE_TIME_LIMIT","KLINE","KLINE_EXEMPT","KLINE_REASON",
"KLINE_WITH_REASON","KNOCK_DELAY","KNOCK_DELAY_CHANNEL","LAZYLINK","LEAF_MASK",
"LINKS_DELAY","LISTEN","T_LOG","LOGGING","LOG_LEVEL","MAX_ACCEPT","MAX_BANS",
"MAX_CHANS_PER_USER","MAX_GLOBAL","MAX_IDENT","MAX_LOCAL","MAX_NICK_CHANGES",
"MAX_NICK_TIME","MAX_NUMBER","MAX_TARGETS","MESSAGE_LOCALE","MIN_NONWILDCARD",
"MIN_NONWILDCARD_SIMPLE","MODULE","MODULES","NAME","NEED_PASSWORD","IS_WEBIRC",
"NETWORK_DESC","NETWORK_NAME","NICK","NICK_CHANGES","NICK_COLLIDE_REALHOST",
"NO_CREATE_ON_SPLIT","NO_JOIN_ON_SPLIT","NO_OPER_FLOOD","NO_TILDE","NOT",
"NUMBER","NUMBER_PER_IDENT","NUMBER_PER_CIDR","NUMBER_PER_IP",
"NUMBER_PER_IP_GLOBAL","OPERATOR","OPERS_BYPASS_CALLERID","OPER_LOG",
"OPER_ONLY_UMODES","OPER_PASS_RESV","OPER_SPY_T","OPER_FARCONNECT",
"OPER_UMODES","JOIN_FLOOD_COUNT","JOIN_FLOOD_TIME","PACE_WAIT",
"PACE_WAIT_SIMPLE","PASSWORD","PATH","PING_COOKIE","PING_TIME","PING_WARNING",
"PORT","QSTRING","QUIET_ON_BAN","REASON","REDIRPORT","REDIRSERV","REGEX_T",
"REHASH","TREJECT_HOLD_TIME","REMOTE","REMOTEBAN","RESTRICT_CHANNELS",
"RESTRICTED","RSA_PRIVATE_KEY_FILE","RSA_PUBLIC_KEY_FILE",
"RSA_CRYPTLINK_KEY_FILE","SSL_CERTIFICATE_FILE","RESV","RESV_EXEMPT","SECONDS",
"MINUTES","HOURS","DAYS","WEEKS","SENDQ","SEND_PASSWORD","SERVERHIDE",
"SERVERINFO","SERVICES","SERVICES_NAME","SERVLINK_PATH","IRCD_SID",
"TKLINE_EXPIRE_NOTICES","T_SHARED","T_CLUSTER","TYPE","SHORT_MOTD","SILENT",
"SPOOF","SPOOF_NOTICE","STATS_E_DISABLED","STATS_I_OPER_ONLY",
"STATS_K_OPER_ONLY","STATS_O_OPER_ONLY","STATS_P_OPER_ONLY","TBOOL","TMASKED",
"T_REJECT","TS_MAX_DELTA","TS_WARN_DELTA","TWODOTS","T_ALL","T_BOTS",
"T_SOFTCALLERID","T_CALLERID","T_CCONN","T_NOCTCP","T_CLIENT_FLOOD","T_DEAF",
"T_DEBUG","T_DRONE","T_EXTERNAL","T_FULL","T_HIDECHANNELS","T_FARCONNECT",
"T_INVISIBLE","T_IPV4","T_IPV6","T_LOCOPS","T_LOGPATH","T_L_CRIT","T_L_DEBUG",
"T_L_ERROR","T_L_INFO","T_L_NOTICE","T_L_TRACE","T_L_WARN","T_MAX_CLIENTS",
"T_NCHANGE","T_OPERWALL","T_REJ","T_SERVNOTICE","T_SKILL","T_SPY","T_SSL",
"T_UMODES","T_UNAUTH","T_UNRESV","T_UNXLINE","T_WALLOP","THROTTLE_TIME",
"THROTTLE_NUM","TOPICBURST","TRUE_NO_OPER_FLOOD","TKLINE","TXLINE","TRESV",
"UNKLINE","USER","USE_EGD","USE_EXCEPT","USE_INVEX","HIDE_KILLER",
"USE_REGEX_BANS","USE_KNOCK","USE_NOCTCP","USE_LOGGING","USE_WHOIS_ACTUALLY",
"VHOST","VHOST6","XLINE","WARN","WARN_NO_NLINE",
};
static const char *yyrule[] = {
"$accept : conf",
"conf :",
"conf : conf conf_item",
"conf_item : admin_entry",
"conf_item : logging_entry",
"conf_item : oper_entry",
"conf_item : channel_entry",
"conf_item : class_entry",
"conf_item : listen_entry",
"conf_item : auth_entry",
"conf_item : serverinfo_entry",
"conf_item : serverhide_entry",
"conf_item : resv_entry",
"conf_item : shared_entry",
"conf_item : cluster_entry",
"conf_item : connect_entry",
"conf_item : kill_entry",
"conf_item : deny_entry",
"conf_item : exempt_entry",
"conf_item : general_entry",
"conf_item : gline_entry",
"conf_item : gecos_entry",
"conf_item : modules_entry",
"conf_item : dnsbl_entry",
"conf_item : error ';'",
"conf_item : error '}'",
"timespec_ :",
"timespec_ : timespec",
"timespec : NUMBER timespec_",
"timespec : NUMBER SECONDS timespec_",
"timespec : NUMBER MINUTES timespec_",
"timespec : NUMBER HOURS timespec_",
"timespec : NUMBER DAYS timespec_",
"timespec : NUMBER WEEKS timespec_",
"sizespec_ :",
"sizespec_ : sizespec",
"sizespec : NUMBER sizespec_",
"sizespec : NUMBER BYTES sizespec_",
"sizespec : NUMBER KBYTES sizespec_",
"sizespec : NUMBER MBYTES sizespec_",
"modules_entry : MODULES '{' modules_items '}' ';'",
"modules_items : modules_items modules_item",
"modules_items : modules_item",
"modules_item : modules_module",
"modules_item : modules_path",
"modules_item : error ';'",
"modules_module : MODULE '=' QSTRING ';'",
"modules_path : PATH '=' QSTRING ';'",
"$$1 :",
"dnsbl_entry : DNSBL $$1 '{' dnsbl_items '}' ';'",
"dnsbl_items : dnsbl_items dnsbl_item",
"dnsbl_items : dnsbl_item",
"dnsbl_item : dnsbl_name",
"dnsbl_item : dnsbl_duration",
"dnsbl_item : dnsbl_reason",
"dnsbl_item : error ';'",
"dnsbl_name : NAME '=' QSTRING ';'",
"dnsbl_duration : DURATION '=' timespec ';'",
"dnsbl_reason : REASON '=' QSTRING ';'",
"serverinfo_entry : SERVERINFO '{' serverinfo_items '}' ';'",
"serverinfo_items : serverinfo_items serverinfo_item",
"serverinfo_items : serverinfo_item",
"serverinfo_item : serverinfo_name",
"serverinfo_item : serverinfo_vhost",
"serverinfo_item : serverinfo_hub",
"serverinfo_item : serverinfo_description",
"serverinfo_item : serverinfo_network_name",
"serverinfo_item : serverinfo_network_desc",
"serverinfo_item : serverinfo_max_clients",
"serverinfo_item : serverinfo_rsa_private_key_file",
"serverinfo_item : serverinfo_rsa_cryptlink_key_file",
"serverinfo_item : serverinfo_vhost6",
"serverinfo_item : serverinfo_sid",
"serverinfo_item : serverinfo_ssl_certificate_file",
"serverinfo_item : error ';'",
"serverinfo_ssl_certificate_file : SSL_CERTIFICATE_FILE '=' QSTRING ';'",
"serverinfo_rsa_private_key_file : RSA_PRIVATE_KEY_FILE '=' QSTRING ';'",
"serverinfo_rsa_cryptlink_key_file : RSA_CRYPTLINK_KEY_FILE '=' QSTRING ';'",
"serverinfo_name : NAME '=' QSTRING ';'",
"serverinfo_sid : IRCD_SID '=' QSTRING ';'",
"serverinfo_description : DESCRIPTION '=' QSTRING ';'",
"serverinfo_network_name : NETWORK_NAME '=' QSTRING ';'",
"serverinfo_network_desc : NETWORK_DESC '=' QSTRING ';'",
"serverinfo_vhost : VHOST '=' QSTRING ';'",
"serverinfo_vhost6 : VHOST6 '=' QSTRING ';'",
"serverinfo_max_clients : T_MAX_CLIENTS '=' NUMBER ';'",
"serverinfo_hub : HUB '=' TBOOL ';'",
"admin_entry : ADMIN '{' admin_items '}' ';'",
"admin_items : admin_items admin_item",
"admin_items : admin_item",
"admin_item : admin_name",
"admin_item : admin_description",
"admin_item : admin_email",
"admin_item : error ';'",
"admin_name : NAME '=' QSTRING ';'",
"admin_email : EMAIL '=' QSTRING ';'",
"admin_description : DESCRIPTION '=' QSTRING ';'",
"logging_entry : LOGGING '{' logging_items '}' ';'",
"logging_items : logging_items logging_item",
"logging_items : logging_item",
"logging_item : logging_path",
"logging_item : logging_oper_log",
"logging_item : logging_log_level",
"logging_item : logging_use_logging",
"logging_item : logging_fuserlog",
"logging_item : logging_foperlog",
"logging_item : logging_fglinelog",
"logging_item : logging_fklinelog",
"logging_item : logging_killlog",
"logging_item : logging_foperspylog",
"logging_item : logging_ioerrlog",
"logging_item : logging_ffailed_operlog",
"logging_item : error ';'",
"logging_path : T_LOGPATH '=' QSTRING ';'",
"logging_oper_log : OPER_LOG '=' QSTRING ';'",
"logging_fuserlog : FUSERLOG '=' QSTRING ';'",
"logging_ffailed_operlog : FFAILED_OPERLOG '=' QSTRING ';'",
"logging_foperlog : FOPERLOG '=' QSTRING ';'",
"logging_foperspylog : FOPERSPYLOG '=' QSTRING ';'",
"logging_fglinelog : FGLINELOG '=' QSTRING ';'",
"logging_fklinelog : FKLINELOG '=' QSTRING ';'",
"logging_ioerrlog : FIOERRLOG '=' QSTRING ';'",
"logging_killlog : FKILLLOG '=' QSTRING ';'",
"logging_log_level : LOG_LEVEL '=' T_L_CRIT ';'",
"logging_log_level : LOG_LEVEL '=' T_L_ERROR ';'",
"logging_log_level : LOG_LEVEL '=' T_L_WARN ';'",
"logging_log_level : LOG_LEVEL '=' T_L_NOTICE ';'",
"logging_log_level : LOG_LEVEL '=' T_L_TRACE ';'",
"logging_log_level : LOG_LEVEL '=' T_L_INFO ';'",
"logging_log_level : LOG_LEVEL '=' T_L_DEBUG ';'",
"logging_use_logging : USE_LOGGING '=' TBOOL ';'",
"$$2 :",
"oper_entry : OPERATOR $$2 oper_name_b '{' oper_items '}' ';'",
"oper_name_b :",
"oper_name_b : oper_name_t",
"oper_items : oper_items oper_item",
"oper_items : oper_item",
"oper_item : oper_name",
"oper_item : oper_user",
"oper_item : oper_password",
"oper_item : oper_hidden_admin",
"oper_item : oper_hidden_oper",
"oper_item : oper_umodes",
"oper_item : oper_class",
"oper_item : oper_global_kill",
"oper_item : oper_remote",
"oper_item : oper_kline",
"oper_item : oper_xline",
"oper_item : oper_unkline",
"oper_item : oper_gline",
"oper_item : oper_nick_changes",
"oper_item : oper_remoteban",
"oper_item : oper_die",
"oper_item : oper_rehash",
"oper_item : oper_admin",
"oper_item : oper_operwall",
"oper_item : oper_encrypted",
"oper_item : oper_rsa_public_key_file",
"oper_item : oper_client_certificate_hash",
"oper_item : oper_spy",
"oper_item : oper_flags",
"oper_item : error ';'",
"oper_name : NAME '=' QSTRING ';'",
"oper_name_t : QSTRING",
"oper_user : USER '=' QSTRING ';'",
"oper_client_certificate_hash : CLIENTCERT_HASH '=' QSTRING ';'",
"oper_password : PASSWORD '=' QSTRING ';'",
"oper_encrypted : ENCRYPTED '=' TBOOL ';'",
"oper_rsa_public_key_file : RSA_PUBLIC_KEY_FILE '=' QSTRING ';'",
"oper_class : CLASS '=' QSTRING ';'",
"$$3 :",
"oper_umodes : T_UMODES $$3 '=' oper_umodes_items ';'",
"oper_umodes_items : oper_umodes_items ',' oper_umodes_item",
"oper_umodes_items : oper_umodes_item",
"oper_umodes_item : T_BOTS",
"oper_umodes_item : T_CCONN",
"oper_umodes_item : T_NOCTCP",
"oper_umodes_item : T_DEAF",
"oper_umodes_item : T_DEBUG",
"oper_umodes_item : T_FULL",
"oper_umodes_item : T_SKILL",
"oper_umodes_item : T_NCHANGE",
"oper_umodes_item : T_REJ",
"oper_umodes_item : T_UNAUTH",
"oper_umodes_item : T_SPY",
"oper_umodes_item : T_EXTERNAL",
"oper_umodes_item : T_OPERWALL",
"oper_umodes_item : T_SERVNOTICE",
"oper_umodes_item : T_INVISIBLE",
"oper_umodes_item : T_WALLOP",
"oper_umodes_item : T_SOFTCALLERID",
"oper_umodes_item : T_CALLERID",
"oper_umodes_item : T_LOCOPS",
"oper_umodes_item : T_HIDECHANNELS",
"oper_umodes_item : T_FARCONNECT",
"oper_global_kill : GLOBAL_KILL '=' TBOOL ';'",
"oper_remote : REMOTE '=' TBOOL ';'",
"oper_remoteban : REMOTEBAN '=' TBOOL ';'",
"oper_kline : KLINE '=' TBOOL ';'",
"oper_xline : XLINE '=' TBOOL ';'",
"oper_unkline : UNKLINE '=' TBOOL ';'",
"oper_gline : GLINE '=' TBOOL ';'",
"oper_nick_changes : NICK_CHANGES '=' TBOOL ';'",
"oper_die : DIE '=' TBOOL ';'",
"oper_rehash : REHASH '=' TBOOL ';'",
"oper_admin : ADMIN '=' TBOOL ';'",
"oper_hidden_admin : HIDDEN_ADMIN '=' TBOOL ';'",
"oper_hidden_oper : HIDDEN_OPER '=' TBOOL ';'",
"oper_spy : OPER_SPY_T '=' TBOOL ';'",
"oper_operwall : T_OPERWALL '=' TBOOL ';'",
"$$4 :",
"oper_flags : IRCD_FLAGS $$4 '=' oper_flags_items ';'",
"oper_flags_items : oper_flags_items ',' oper_flags_item",
"oper_flags_items : oper_flags_item",
"$$5 :",
"oper_flags_item : NOT $$5 oper_flags_item_atom",
"$$6 :",
"oper_flags_item : $$6 oper_flags_item_atom",
"oper_flags_item_atom : GLOBAL_KILL",
"oper_flags_item_atom : REMOTE",
"oper_flags_item_atom : KLINE",
"oper_flags_item_atom : UNKLINE",
"oper_flags_item_atom : XLINE",
"oper_flags_item_atom : GLINE",
"oper_flags_item_atom : DIE",
"oper_flags_item_atom : REHASH",
"oper_flags_item_atom : ADMIN",
"oper_flags_item_atom : HIDDEN_ADMIN",
"oper_flags_item_atom : NICK_CHANGES",
"oper_flags_item_atom : T_OPERWALL",
"oper_flags_item_atom : OPER_SPY_T",
"oper_flags_item_atom : HIDDEN_OPER",
"oper_flags_item_atom : REMOTEBAN",
"oper_flags_item_atom : ENCRYPTED",
"oper_flags_item_atom : OPER_FARCONNECT",
"$$7 :",
"class_entry : CLASS $$7 class_name_b '{' class_items '}' ';'",
"class_name_b :",
"class_name_b : class_name_t",
"class_items : class_items class_item",
"class_items : class_item",
"class_item : class_name",
"class_item : class_cidr_bitlen_ipv4",
"class_item : class_cidr_bitlen_ipv6",
"class_item : class_ping_time",
"class_item : class_ping_warning",
"class_item : class_number_per_cidr",
"class_item : class_number_per_ip",
"class_item : class_connectfreq",
"class_item : class_max_number",
"class_item : class_max_global",
"class_item : class_max_local",
"class_item : class_max_ident",
"class_item : class_sendq",
"class_item : error ';'",
"class_name : NAME '=' QSTRING ';'",
"class_name_t : QSTRING",
"class_ping_time : PING_TIME '=' timespec ';'",
"class_ping_warning : PING_WARNING '=' timespec ';'",
"class_number_per_ip : NUMBER_PER_IP '=' NUMBER ';'",
"class_connectfreq : CONNECTFREQ '=' timespec ';'",
"class_max_number : MAX_NUMBER '=' NUMBER ';'",
"class_max_global : MAX_GLOBAL '=' NUMBER ';'",
"class_max_local : MAX_LOCAL '=' NUMBER ';'",
"class_max_ident : MAX_IDENT '=' NUMBER ';'",
"class_sendq : SENDQ '=' sizespec ';'",
"class_cidr_bitlen_ipv4 : CIDR_BITLEN_IPV4 '=' NUMBER ';'",
"class_cidr_bitlen_ipv6 : CIDR_BITLEN_IPV6 '=' NUMBER ';'",
"class_number_per_cidr : NUMBER_PER_CIDR '=' NUMBER ';'",
"$$8 :",
"listen_entry : LISTEN $$8 '{' listen_items '}' ';'",
"$$9 :",
"listen_flags : IRCD_FLAGS $$9 '=' listen_flags_items ';'",
"listen_flags_items : listen_flags_items ',' listen_flags_item",
"listen_flags_items : listen_flags_item",
"listen_flags_item : T_SSL",
"listen_flags_item : HIDDEN",
"listen_items : listen_items listen_item",
"listen_items : listen_item",
"listen_item : listen_port",
"listen_item : listen_flags",
"listen_item : listen_address",
"listen_item : listen_host",
"listen_item : error ';'",
"$$10 :",
"listen_port : PORT '=' port_items $$10 ';'",
"port_items : port_items ',' port_item",
"port_items : port_item",
"port_item : NUMBER",
"port_item : NUMBER TWODOTS NUMBER",
"listen_address : IP '=' QSTRING ';'",
"listen_host : HOST '=' QSTRING ';'",
"$$11 :",
"auth_entry : IRCD_AUTH $$11 '{' auth_items '}' ';'",
"auth_items : auth_items auth_item",
"auth_items : auth_item",
"auth_item : auth_user",
"auth_item : auth_passwd",
"auth_item : auth_class",
"auth_item : auth_flags",
"auth_item : auth_kline_exempt",
"auth_item : auth_need_ident",
"auth_item : auth_exceed_limit",
"auth_item : auth_no_tilde",
"auth_item : auth_gline_exempt",
"auth_item : auth_spoof",
"auth_item : auth_spoof_notice",
"auth_item : auth_webirc",
"auth_item : auth_redir_serv",
"auth_item : auth_redir_port",
"auth_item : auth_can_flood",
"auth_item : auth_need_password",
"auth_item : auth_encrypted",
"auth_item : auth_client_certificate_hash",
"auth_item : error ';'",
"auth_user : USER '=' QSTRING ';'",
"auth_passwd : PASSWORD '=' QSTRING ';'",
"auth_client_certificate_hash : CLIENTCERT_HASH '=' QSTRING ';'",
"auth_spoof_notice : SPOOF_NOTICE '=' TBOOL ';'",
"auth_class : CLASS '=' QSTRING ';'",
"auth_encrypted : ENCRYPTED '=' TBOOL ';'",
"$$12 :",
"auth_flags : IRCD_FLAGS $$12 '=' auth_flags_items ';'",
"auth_flags_items : auth_flags_items ',' auth_flags_item",
"auth_flags_items : auth_flags_item",
"$$13 :",
"auth_flags_item : NOT $$13 auth_flags_item_atom",
"$$14 :",
"auth_flags_item : $$14 auth_flags_item_atom",
"auth_flags_item_atom : SPOOF_NOTICE",
"auth_flags_item_atom : EXCEED_LIMIT",
"auth_flags_item_atom : KLINE_EXEMPT",
"auth_flags_item_atom : NEED_IDENT",
"auth_flags_item_atom : CAN_FLOOD",
"auth_flags_item_atom : CAN_IDLE",
"auth_flags_item_atom : NO_TILDE",
"auth_flags_item_atom : GLINE_EXEMPT",
"auth_flags_item_atom : RESV_EXEMPT",
"auth_flags_item_atom : IS_WEBIRC",
"auth_flags_item_atom : NEED_PASSWORD",
"auth_kline_exempt : KLINE_EXEMPT '=' TBOOL ';'",
"auth_need_ident : NEED_IDENT '=' TBOOL ';'",
"auth_exceed_limit : EXCEED_LIMIT '=' TBOOL ';'",
"auth_can_flood : CAN_FLOOD '=' TBOOL ';'",
"auth_no_tilde : NO_TILDE '=' TBOOL ';'",
"auth_gline_exempt : GLINE_EXEMPT '=' TBOOL ';'",
"auth_spoof : SPOOF '=' QSTRING ';'",
"auth_redir_serv : REDIRSERV '=' QSTRING ';'",
"auth_redir_port : REDIRPORT '=' NUMBER ';'",
"auth_webirc : IS_WEBIRC '=' TBOOL ';'",
"auth_need_password : NEED_PASSWORD '=' TBOOL ';'",
"$$15 :",
"resv_entry : RESV $$15 '{' resv_items '}' ';'",
"resv_items : resv_items resv_item",
"resv_items : resv_item",
"resv_item : resv_creason",
"resv_item : resv_channel",
"resv_item : resv_nick",
"resv_item : error ';'",
"resv_creason : REASON '=' QSTRING ';'",
"resv_channel : CHANNEL '=' QSTRING ';'",
"resv_nick : NICK '=' QSTRING ';'",
"$$16 :",
"shared_entry : T_SHARED $$16 '{' shared_items '}' ';'",
"shared_items : shared_items shared_item",
"shared_items : shared_item",
"shared_item : shared_name",
"shared_item : shared_user",
"shared_item : shared_type",
"shared_item : error ';'",
"shared_name : NAME '=' QSTRING ';'",
"shared_user : USER '=' QSTRING ';'",
"$$17 :",
"shared_type : TYPE $$17 '=' shared_types ';'",
"shared_types : shared_types ',' shared_type_item",
"shared_types : shared_type_item",
"shared_type_item : KLINE",
"shared_type_item : TKLINE",
"shared_type_item : UNKLINE",
"shared_type_item : XLINE",
"shared_type_item : TXLINE",
"shared_type_item : T_UNXLINE",
"shared_type_item : RESV",
"shared_type_item : TRESV",
"shared_type_item : T_UNRESV",
"shared_type_item : T_LOCOPS",
"shared_type_item : SERVICES",
"shared_type_item : REHASH",
"shared_type_item : T_ALL",
"$$18 :",
"cluster_entry : T_CLUSTER $$18 '{' cluster_items '}' ';'",
"cluster_items : cluster_items cluster_item",
"cluster_items : cluster_item",
"cluster_item : cluster_name",
"cluster_item : cluster_type",
"cluster_item : error ';'",
"cluster_name : NAME '=' QSTRING ';'",
"$$19 :",
"cluster_type : TYPE $$19 '=' cluster_types ';'",
"cluster_types : cluster_types ',' cluster_type_item",
"cluster_types : cluster_type_item",
"cluster_type_item : KLINE",
"cluster_type_item : TKLINE",
"cluster_type_item : UNKLINE",
"cluster_type_item : XLINE",
"cluster_type_item : TXLINE",
"cluster_type_item : T_UNXLINE",
"cluster_type_item : RESV",
"cluster_type_item : TRESV",
"cluster_type_item : T_UNRESV",
"cluster_type_item : T_LOCOPS",
"cluster_type_item : T_ALL",
"$$20 :",
"connect_entry : CONNECT $$20 connect_name_b '{' connect_items '}' ';'",
"connect_name_b :",
"connect_name_b : connect_name_t",
"connect_items : connect_items connect_item",
"connect_items : connect_item",
"connect_item : connect_name",
"connect_item : connect_host",
"connect_item : connect_vhost",
"connect_item : connect_send_password",
"connect_item : connect_accept_password",
"connect_item : connect_aftype",
"connect_item : connect_port",
"connect_item : connect_fakename",
"connect_item : connect_flags",
"connect_item : connect_hub_mask",
"connect_item : connect_leaf_mask",
"connect_item : connect_class",
"connect_item : connect_auto",
"connect_item : connect_encrypted",
"connect_item : connect_compressed",
"connect_item : connect_cryptlink",
"connect_item : connect_rsa_public_key_file",
"connect_item : connect_cipher_preference",
"connect_item : connect_topicburst",
"connect_item : error ';'",
"connect_name : NAME '=' QSTRING ';'",
"connect_name_t : QSTRING",
"connect_host : HOST '=' QSTRING ';'",
"connect_vhost : VHOST '=' QSTRING ';'",
"connect_send_password : SEND_PASSWORD '=' QSTRING ';'",
"connect_accept_password : ACCEPT_PASSWORD '=' QSTRING ';'",
"connect_port : PORT '=' NUMBER ';'",
"connect_aftype : AFTYPE '=' T_IPV4 ';'",
"connect_aftype : AFTYPE '=' T_IPV6 ';'",
"connect_fakename : FAKENAME '=' QSTRING ';'",
"$$21 :",
"connect_flags : IRCD_FLAGS $$21 '=' connect_flags_items ';'",
"connect_flags_items : connect_flags_items ',' connect_flags_item",
"connect_flags_items : connect_flags_item",
"$$22 :",
"connect_flags_item : NOT $$22 connect_flags_item_atom",
"$$23 :",
"connect_flags_item : $$23 connect_flags_item_atom",
"connect_flags_item_atom : LAZYLINK",
"connect_flags_item_atom : COMPRESSED",
"connect_flags_item_atom : CRYPTLINK",
"connect_flags_item_atom : AUTOCONN",
"connect_flags_item_atom : BURST_AWAY",
"connect_flags_item_atom : TOPICBURST",
"connect_rsa_public_key_file : RSA_PUBLIC_KEY_FILE '=' QSTRING ';'",
"connect_encrypted : ENCRYPTED '=' TBOOL ';'",
"connect_cryptlink : CRYPTLINK '=' TBOOL ';'",
"connect_compressed : COMPRESSED '=' TBOOL ';'",
"connect_auto : AUTOCONN '=' TBOOL ';'",
"connect_topicburst : TOPICBURST '=' TBOOL ';'",
"connect_hub_mask : HUB_MASK '=' QSTRING ';'",
"connect_leaf_mask : LEAF_MASK '=' QSTRING ';'",
"connect_class : CLASS '=' QSTRING ';'",
"connect_cipher_preference : CIPHER_PREFERENCE '=' QSTRING ';'",
"$$24 :",
"kill_entry : KILL $$24 '{' kill_items '}' ';'",
"$$25 :",
"kill_type : TYPE $$25 '=' kill_type_items ';'",
"kill_type_items : kill_type_items ',' kill_type_item",
"kill_type_items : kill_type_item",
"kill_type_item : REGEX_T",
"kill_items : kill_items kill_item",
"kill_items : kill_item",
"kill_item : kill_user",
"kill_item : kill_reason",
"kill_item : kill_type",
"kill_item : error",
"kill_user : USER '=' QSTRING ';'",
"kill_reason : REASON '=' QSTRING ';'",
"$$26 :",
"deny_entry : DENY $$26 '{' deny_items '}' ';'",
"deny_items : deny_items deny_item",
"deny_items : deny_item",
"deny_item : deny_ip",
"deny_item : deny_reason",
"deny_item : error",
"deny_ip : IP '=' QSTRING ';'",
"deny_reason : REASON '=' QSTRING ';'",
"exempt_entry : EXEMPT '{' exempt_items '}' ';'",
"exempt_items : exempt_items exempt_item",
"exempt_items : exempt_item",
"exempt_item : exempt_ip",
"exempt_item : exempt_client_certificate_hash",
"exempt_item : error",
"exempt_ip : IP '=' QSTRING ';'",
"exempt_client_certificate_hash : CLIENTCERT_HASH '=' QSTRING ';'",
"$$27 :",
"gecos_entry : GECOS $$27 '{' gecos_items '}' ';'",
"$$28 :",
"gecos_flags : TYPE $$28 '=' gecos_flags_items ';'",
"gecos_flags_items : gecos_flags_items ',' gecos_flags_item",
"gecos_flags_items : gecos_flags_item",
"gecos_flags_item : REGEX_T",
"gecos_items : gecos_items gecos_item",
"gecos_items : gecos_item",
"gecos_item : gecos_name",
"gecos_item : gecos_reason",
"gecos_item : gecos_flags",
"gecos_item : error",
"gecos_name : NAME '=' QSTRING ';'",
"gecos_reason : REASON '=' QSTRING ';'",
"general_entry : GENERAL '{' general_items '}' ';'",
"general_items : general_items general_item",
"general_items : general_item",
"general_item : general_hide_spoof_ips",
"general_item : general_ignore_bogus_ts",
"general_item : general_failed_oper_notice",
"general_item : general_anti_nick_flood",
"general_item : general_max_nick_time",
"general_item : general_max_nick_changes",
"general_item : general_max_accept",
"general_item : general_anti_spam_exit_message_time",
"general_item : general_anti_spam_connect_numeric",
"general_item : general_ts_warn_delta",
"general_item : general_ts_max_delta",
"general_item : general_kill_chase_time_limit",
"general_item : general_kline_with_reason",
"general_item : general_kline_reason",
"general_item : general_invisible_on_connect",
"general_item : general_warn_no_nline",
"general_item : general_dots_in_ident",
"general_item : general_stats_o_oper_only",
"general_item : general_stats_k_oper_only",
"general_item : general_pace_wait",
"general_item : general_stats_i_oper_only",
"general_item : general_pace_wait_simple",
"general_item : general_stats_P_oper_only",
"general_item : general_short_motd",
"general_item : general_no_oper_flood",
"general_item : general_true_no_oper_flood",
"general_item : general_oper_pass_resv",
"general_item : general_idletime",
"general_item : general_message_locale",
"general_item : general_oper_only_umodes",
"general_item : general_max_targets",
"general_item : general_use_egd",
"general_item : general_egdpool_path",
"general_item : general_oper_umodes",
"general_item : general_caller_id_wait",
"general_item : general_opers_bypass_callerid",
"general_item : general_default_floodcount",
"general_item : general_min_nonwildcard",
"general_item : general_min_nonwildcard_simple",
"general_item : general_servlink_path",
"general_item : general_disable_remote_commands",
"general_item : general_default_cipher_preference",
"general_item : general_stats_e_disabled",
"general_item : general_compression_level",
"general_item : general_client_flood",
"general_item : general_throttle_num",
"general_item : general_throttle_time",
"general_item : general_havent_read_conf",
"general_item : general_dot_in_ip6_addr",
"general_item : general_ping_cookie",
"general_item : general_disable_auth",
"general_item : general_burst_away",
"general_item : general_tkline_expire_notices",
"general_item : general_gline_min_cidr",
"general_item : general_gline_min_cidr6",
"general_item : general_use_whois_actually",
"general_item : general_reject_hold_time",
"general_item : general_hide_killer",
"general_item : general_cloak_key1",
"general_item : general_cloak_key2",
"general_item : general_cloak_key3",
"general_item : general_cloak_whois_actually",
"general_item : general_account_whois",
"general_item : general_services_name",
"general_item : general_nick_collide_realhost",
"general_item : error",
"general_gline_min_cidr : GLINE_MIN_CIDR '=' NUMBER ';'",
"general_gline_min_cidr6 : GLINE_MIN_CIDR6 '=' NUMBER ';'",
"general_burst_away : BURST_AWAY '=' TBOOL ';'",
"general_use_whois_actually : USE_WHOIS_ACTUALLY '=' TBOOL ';'",
"general_nick_collide_realhost : NICK_COLLIDE_REALHOST '=' TBOOL ';'",
"general_reject_hold_time : TREJECT_HOLD_TIME '=' timespec ';'",
"general_tkline_expire_notices : TKLINE_EXPIRE_NOTICES '=' TBOOL ';'",
"general_kill_chase_time_limit : KILL_CHASE_TIME_LIMIT '=' NUMBER ';'",
"general_hide_spoof_ips : HIDE_SPOOF_IPS '=' TBOOL ';'",
"general_ignore_bogus_ts : IGNORE_BOGUS_TS '=' TBOOL ';'",
"general_disable_remote_commands : DISABLE_REMOTE_COMMANDS '=' TBOOL ';'",
"general_failed_oper_notice : FAILED_OPER_NOTICE '=' TBOOL ';'",
"general_anti_nick_flood : ANTI_NICK_FLOOD '=' TBOOL ';'",
"general_max_nick_time : MAX_NICK_TIME '=' timespec ';'",
"general_max_nick_changes : MAX_NICK_CHANGES '=' NUMBER ';'",
"general_max_accept : MAX_ACCEPT '=' NUMBER ';'",
"general_anti_spam_exit_message_time : ANTI_SPAM_EXIT_MESSAGE_TIME '=' timespec ';'",
"general_anti_spam_connect_numeric : ANTI_SPAM_CONNECT_NUMERIC '=' TBOOL ';'",
"general_ts_warn_delta : TS_WARN_DELTA '=' timespec ';'",
"general_ts_max_delta : TS_MAX_DELTA '=' timespec ';'",
"general_havent_read_conf : HAVENT_READ_CONF '=' NUMBER ';'",
"general_kline_with_reason : KLINE_WITH_REASON '=' TBOOL ';'",
"general_kline_reason : KLINE_REASON '=' QSTRING ';'",
"general_cloak_key1 : CLOAK_KEY1 '=' QSTRING ';'",
"general_cloak_key2 : CLOAK_KEY2 '=' QSTRING ';'",
"general_cloak_key3 : CLOAK_KEY3 '=' QSTRING ';'",
"general_cloak_whois_actually : CLOAK_WHOIS_ACTUALLY '=' TBOOL ';'",
"general_account_whois : ACCOUNT_WHOIS '=' TBOOL ';'",
"general_services_name : SERVICES_NAME '=' QSTRING ';'",
"general_invisible_on_connect : INVISIBLE_ON_CONNECT '=' TBOOL ';'",
"general_warn_no_nline : WARN_NO_NLINE '=' TBOOL ';'",
"general_stats_e_disabled : STATS_E_DISABLED '=' TBOOL ';'",
"general_stats_o_oper_only : STATS_O_OPER_ONLY '=' TBOOL ';'",
"general_stats_P_oper_only : STATS_P_OPER_ONLY '=' TBOOL ';'",
"general_hide_killer : HIDE_KILLER '=' TBOOL ';'",
"general_stats_k_oper_only : STATS_K_OPER_ONLY '=' TBOOL ';'",
"general_stats_k_oper_only : STATS_K_OPER_ONLY '=' TMASKED ';'",
"general_stats_i_oper_only : STATS_I_OPER_ONLY '=' TBOOL ';'",
"general_stats_i_oper_only : STATS_I_OPER_ONLY '=' TMASKED ';'",
"general_pace_wait : PACE_WAIT '=' timespec ';'",
"general_caller_id_wait : CALLER_ID_WAIT '=' timespec ';'",
"general_opers_bypass_callerid : OPERS_BYPASS_CALLERID '=' TBOOL ';'",
"general_pace_wait_simple : PACE_WAIT_SIMPLE '=' timespec ';'",
"general_short_motd : SHORT_MOTD '=' TBOOL ';'",
"general_no_oper_flood : NO_OPER_FLOOD '=' TBOOL ';'",
"general_true_no_oper_flood : TRUE_NO_OPER_FLOOD '=' TBOOL ';'",
"general_oper_pass_resv : OPER_PASS_RESV '=' TBOOL ';'",
"general_message_locale : MESSAGE_LOCALE '=' QSTRING ';'",
"general_idletime : IDLETIME '=' timespec ';'",
"general_dots_in_ident : DOTS_IN_IDENT '=' NUMBER ';'",
"general_max_targets : MAX_TARGETS '=' NUMBER ';'",
"general_servlink_path : SERVLINK_PATH '=' QSTRING ';'",
"general_default_cipher_preference : DEFAULT_CIPHER_PREFERENCE '=' QSTRING ';'",
"general_compression_level : COMPRESSION_LEVEL '=' NUMBER ';'",
"general_use_egd : USE_EGD '=' TBOOL ';'",
"general_egdpool_path : EGDPOOL_PATH '=' QSTRING ';'",
"general_ping_cookie : PING_COOKIE '=' TBOOL ';'",
"general_disable_auth : DISABLE_AUTH '=' TBOOL ';'",
"general_throttle_num : THROTTLE_NUM '=' NUMBER ';'",
"general_throttle_time : THROTTLE_TIME '=' timespec ';'",
"$$29 :",
"general_oper_umodes : OPER_UMODES $$29 '=' umode_oitems ';'",
"umode_oitems : umode_oitems ',' umode_oitem",
"umode_oitems : umode_oitem",
"umode_oitem : T_BOTS",
"umode_oitem : T_CCONN",
"umode_oitem : T_NOCTCP",
"umode_oitem : T_DEAF",
"umode_oitem : T_DEBUG",
"umode_oitem : T_FULL",
"umode_oitem : T_SKILL",
"umode_oitem : T_NCHANGE",
"umode_oitem : T_REJ",
"umode_oitem : T_UNAUTH",
"umode_oitem : T_SPY",
"umode_oitem : T_EXTERNAL",
"umode_oitem : T_OPERWALL",
"umode_oitem : T_SERVNOTICE",
"umode_oitem : T_INVISIBLE",
"umode_oitem : T_WALLOP",
"umode_oitem : T_SOFTCALLERID",
"umode_oitem : T_CALLERID",
"umode_oitem : T_LOCOPS",
"umode_oitem : T_HIDECHANNELS",
"umode_oitem : T_FARCONNECT",
"$$30 :",
"general_oper_only_umodes : OPER_ONLY_UMODES $$30 '=' umode_items ';'",
"umode_items : umode_items ',' umode_item",
"umode_items : umode_item",
"umode_item : T_BOTS",
"umode_item : T_CCONN",
"umode_item : T_NOCTCP",
"umode_item : T_DEAF",
"umode_item : T_DEBUG",
"umode_item : T_FULL",
"umode_item : T_SKILL",
"umode_item : T_NCHANGE",
"umode_item : T_REJ",
"umode_item : T_UNAUTH",
"umode_item : T_SPY",
"umode_item : T_EXTERNAL",
"umode_item : T_OPERWALL",
"umode_item : T_SERVNOTICE",
"umode_item : T_INVISIBLE",
"umode_item : T_WALLOP",
"umode_item : T_SOFTCALLERID",
"umode_item : T_CALLERID",
"umode_item : T_LOCOPS",
"umode_item : T_HIDECHANNELS",
"umode_item : T_FARCONNECT",
"general_min_nonwildcard : MIN_NONWILDCARD '=' NUMBER ';'",
"general_min_nonwildcard_simple : MIN_NONWILDCARD_SIMPLE '=' NUMBER ';'",
"general_default_floodcount : DEFAULT_FLOODCOUNT '=' NUMBER ';'",
"general_client_flood : T_CLIENT_FLOOD '=' sizespec ';'",
"general_dot_in_ip6_addr : DOT_IN_IP6_ADDR '=' TBOOL ';'",
"$$31 :",
"gline_entry : GLINES $$31 '{' gline_items '}' ';'",
"gline_items : gline_items gline_item",
"gline_items : gline_item",
"gline_item : gline_enable",
"gline_item : gline_duration",
"gline_item : gline_logging",
"gline_item : gline_user",
"gline_item : gline_server",
"gline_item : gline_action",
"gline_item : error",
"gline_enable : ENABLE '=' TBOOL ';'",
"gline_duration : DURATION '=' timespec ';'",
"$$32 :",
"gline_logging : LOGGING $$32 '=' gline_logging_types ';'",
"gline_logging_types : gline_logging_types ',' gline_logging_type_item",
"gline_logging_types : gline_logging_type_item",
"gline_logging_type_item : T_REJECT",
"gline_logging_type_item : T_BLOCK",
"gline_user : USER '=' QSTRING ';'",
"gline_server : NAME '=' QSTRING ';'",
"$$33 :",
"gline_action : ACTION $$33 '=' gdeny_types ';'",
"gdeny_types : gdeny_types ',' gdeny_type_item",
"gdeny_types : gdeny_type_item",
"gdeny_type_item : T_REJECT",
"gdeny_type_item : T_BLOCK",
"channel_entry : CHANNEL '{' channel_items '}' ';'",
"channel_items : channel_items channel_item",
"channel_items : channel_item",
"channel_item : channel_disable_local_channels",
"channel_item : channel_use_except",
"channel_item : channel_use_invex",
"channel_item : channel_use_knock",
"channel_item : channel_use_noctcp",
"channel_item : channel_use_regex_bans",
"channel_item : channel_max_bans",
"channel_item : channel_knock_delay",
"channel_item : channel_knock_delay_channel",
"channel_item : channel_max_chans_per_user",
"channel_item : channel_quiet_on_ban",
"channel_item : channel_default_split_user_count",
"channel_item : channel_default_split_server_count",
"channel_item : channel_no_create_on_split",
"channel_item : channel_restrict_channels",
"channel_item : channel_no_join_on_split",
"channel_item : channel_burst_topicwho",
"channel_item : channel_jflood_count",
"channel_item : channel_jflood_time",
"channel_item : channel_disable_fake_channels",
"channel_item : channel_cycle_on_hostchange",
"channel_item : error",
"channel_cycle_on_hostchange : CYCLE_ON_HOSTCHANGE '=' TBOOL ';'",
"channel_disable_fake_channels : DISABLE_FAKE_CHANNELS '=' TBOOL ';'",
"channel_restrict_channels : RESTRICT_CHANNELS '=' TBOOL ';'",
"channel_disable_local_channels : DISABLE_LOCAL_CHANNELS '=' TBOOL ';'",
"channel_use_except : USE_EXCEPT '=' TBOOL ';'",
"channel_use_invex : USE_INVEX '=' TBOOL ';'",
"channel_use_regex_bans : USE_REGEX_BANS '=' TBOOL ';'",
"channel_use_knock : USE_KNOCK '=' TBOOL ';'",
"channel_use_noctcp : USE_NOCTCP '=' TBOOL ';'",
"channel_knock_delay : KNOCK_DELAY '=' timespec ';'",
"channel_knock_delay_channel : KNOCK_DELAY_CHANNEL '=' timespec ';'",
"channel_max_chans_per_user : MAX_CHANS_PER_USER '=' NUMBER ';'",
"channel_quiet_on_ban : QUIET_ON_BAN '=' TBOOL ';'",
"channel_max_bans : MAX_BANS '=' NUMBER ';'",
"channel_default_split_user_count : DEFAULT_SPLIT_USER_COUNT '=' NUMBER ';'",
"channel_default_split_server_count : DEFAULT_SPLIT_SERVER_COUNT '=' NUMBER ';'",
"channel_no_create_on_split : NO_CREATE_ON_SPLIT '=' TBOOL ';'",
"channel_no_join_on_split : NO_JOIN_ON_SPLIT '=' TBOOL ';'",
"channel_burst_topicwho : BURST_TOPICWHO '=' TBOOL ';'",
"channel_jflood_count : JOIN_FLOOD_COUNT '=' NUMBER ';'",
"channel_jflood_time : JOIN_FLOOD_TIME '=' timespec ';'",
"serverhide_entry : SERVERHIDE '{' serverhide_items '}' ';'",
"serverhide_items : serverhide_items serverhide_item",
"serverhide_items : serverhide_item",
"serverhide_item : serverhide_flatten_links",
"serverhide_item : serverhide_hide_servers",
"serverhide_item : serverhide_links_delay",
"serverhide_item : serverhide_disable_hidden",
"serverhide_item : serverhide_hidden",
"serverhide_item : serverhide_hidden_name",
"serverhide_item : serverhide_hide_server_ips",
"serverhide_item : error",
"serverhide_flatten_links : FLATTEN_LINKS '=' TBOOL ';'",
"serverhide_hide_servers : HIDE_SERVERS '=' TBOOL ';'",
"serverhide_hidden_name : HIDDEN_NAME '=' QSTRING ';'",
"serverhide_links_delay : LINKS_DELAY '=' timespec ';'",
"serverhide_hidden : HIDDEN '=' TBOOL ';'",
"serverhide_disable_hidden : DISABLE_HIDDEN '=' TBOOL ';'",
"serverhide_hide_server_ips : HIDE_SERVER_IPS '=' TBOOL ';'",

};
#endif

int      yydebug;
int      yynerrs;

int      yyerrflag;
int      yychar;
YYSTYPE  yyval;
YYSTYPE  yylval;

/* define the initial stack-sizes */
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH  YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH  10000
#endif
#endif

#define YYINITSTACKSIZE 200

typedef struct {
    unsigned stacksize;
    short    *s_base;
    short    *s_mark;
    short    *s_last;
    YYSTYPE  *l_base;
    YYSTYPE  *l_mark;
} YYSTACKDATA;
/* variables for the parser stack */
static YYSTACKDATA yystack;

#if YYDEBUG
#include <stdio.h>		/* needed for printf */
#endif

#include <stdlib.h>	/* needed for malloc, etc */
#include <string.h>	/* needed for memset */

/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack(YYSTACKDATA *data)
{
    int i;
    unsigned newsize;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;

    i = (int) (data->s_mark - data->s_base);
    newss = (short *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return -1;

    data->s_base = newss;
    data->s_mark = newss + i;

    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return -1;

    data->l_base = newvs;
    data->l_mark = newvs + i;

    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;
    return 0;
}

#if YYPURE || defined(YY_NO_LEAKS)
static void yyfreestack(YYSTACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
    memset(data, 0, sizeof(*data));
}
#else
#define yyfreestack(data) /* nothing */
#endif

#define YYABORT  goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab

int
YYPARSE_DECL()
{
    int yym, yyn, yystate;
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")) != 0)
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;

#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif

    if (yystack.s_base == NULL && yygrowstack(&yystack)) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
    yystate = 0;
    *yystack.s_mark = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
        {
            goto yyoverflow;
        }
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
        yychar = YYEMPTY;
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;

    yyerror("syntax error");

    goto yyerrlab;

yyerrlab:
    ++yynerrs;

yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yystack.s_mark]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yystack.s_mark, yytable[yyn]);
#endif
                if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
                {
                    goto yyoverflow;
                }
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yystack.s_mark);
#endif
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
                --yystack.s_mark;
                --yystack.l_mark;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = YYEMPTY;
        goto yyloop;
    }

yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    if (yym)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
    switch (yyn)
    {
case 26:
#line 447 "ircd_parser.y"
	{ yyval.number = 0; }
break;
case 28:
#line 449 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-1].number + yystack.l_mark[0].number;
		}
break;
case 29:
#line 453 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number + yystack.l_mark[0].number;
		}
break;
case 30:
#line 457 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 + yystack.l_mark[0].number;
		}
break;
case 31:
#line 461 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 * 60 + yystack.l_mark[0].number;
		}
break;
case 32:
#line 465 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 * 60 * 24 + yystack.l_mark[0].number;
		}
break;
case 33:
#line 469 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 * 60 * 24 * 7 + yystack.l_mark[0].number;
		}
break;
case 34:
#line 474 "ircd_parser.y"
	{ yyval.number = 0; }
break;
case 36:
#line 475 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-1].number + yystack.l_mark[0].number; }
break;
case 37:
#line 476 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-2].number + yystack.l_mark[0].number; }
break;
case 38:
#line 477 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-2].number * 1024 + yystack.l_mark[0].number; }
break;
case 39:
#line 478 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-2].number * 1024 * 1024 + yystack.l_mark[0].number; }
break;
case 46:
#line 492 "ircd_parser.y"
	{
#ifndef STATIC_MODULES /* NOOP in the static case */
  if (ypass == 2)
  {
    char *m_bn;

    m_bn = basename(yylval.string);

    /* I suppose we should just ignore it if it is already loaded(since
     * otherwise we would flood the opers on rehash) -A1kmm.
     */
    add_conf_module(yylval.string);
  }
#endif
}
break;
case 47:
#line 509 "ircd_parser.y"
	{
#ifndef STATIC_MODULES
  if (ypass == 2)
    mod_add_path(yylval.string);
#endif
}
break;
case 48:
#line 521 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(DNSBL_TYPE);
    yy_dconf = map_to_conf(yy_conf);
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 49:
#line 533 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_dconf->reason == NULL)
      delete_conf_item(yy_conf);
  }
}
break;
case 56:
#line 546 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 57:
#line 555 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_dconf->duration = yystack.l_mark[-1].number;
}
break;
case 58:
#line 561 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_dconf->reason);
    DupString(yy_dconf->reason, yylval.string);
  }
}
break;
case 75:
#line 586 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2 && ServerInfo.ctx) 
  {
    if (!ServerInfo.rsa_private_key_file)
    {
      yyerror("No rsa_private_key_file specified, SSL disabled");
      break;
    }

    if (SSL_CTX_use_certificate_chain_file(ServerInfo.ctx, yylval.string) <= 0)
    {
      yyerror(ERR_lib_error_string(ERR_get_error()));
      break;
    }

    if (SSL_CTX_use_PrivateKey_file(ServerInfo.ctx,
      ServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0)
    {
      yyerror(ERR_lib_error_string(ERR_get_error()));
      break;
    }

    if (!SSL_CTX_check_private_key(ServerInfo.ctx))
    {
      yyerror("RSA private key does not match the SSL certificate public key!");
      break;
    }
  }
#endif
}
break;
case 76:
#line 619 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 1)
  {
    BIO *file;

    if (ServerInfo.rsa_private_key)
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;
    }

    if (ServerInfo.rsa_private_key_file)
    {
      MyFree(ServerInfo.rsa_private_key_file);
      ServerInfo.rsa_private_key_file = NULL;
    }

    DupString(ServerInfo.rsa_private_key_file, yylval.string);

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("File open failed, ignoring");
      break;
    }

    ServerInfo.rsa_private_key = (RSA *)PEM_read_bio_RSAPrivateKey(file, NULL,
      0, NULL);

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);

    if (ServerInfo.rsa_private_key == NULL)
    {
      yyerror("Couldn't extract key, ignoring");
      break;
    }

    if (!RSA_check_key(ServerInfo.rsa_private_key))
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;

      yyerror("Invalid key, ignoring");
      break;
    }

    if (RSA_size(ServerInfo.rsa_private_key) < 128)
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;

      yyerror("Ignoring rsa_private_key_file -- need at least a 1024 bit key size");
    }
  }
#endif
}
break;
case 77:
#line 678 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 1)
  {
    BIO *file;

    if (ServerInfo.cryptlink_private_key)
    {
      RSA_free(ServerInfo.cryptlink_private_key);
      ServerInfo.cryptlink_private_key = NULL;
    }

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("File open failed, ignoring");
      break;
    }

    ServerInfo.cryptlink_private_key = (RSA *)PEM_read_bio_RSAPrivateKey(file, NULL,
      0, NULL);

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);

    if (ServerInfo.cryptlink_private_key == NULL)
    {
      yyerror("Couldn't extract key, ignoring");
      break;
    }

    if (!RSA_check_key(ServerInfo.cryptlink_private_key))
    {
      RSA_free(ServerInfo.cryptlink_private_key);
      ServerInfo.cryptlink_private_key = NULL;

      yyerror("Invalid key, ignoring");
      break;
    }

    if (RSA_size(ServerInfo.cryptlink_private_key) < 128)
    {
      RSA_free(ServerInfo.cryptlink_private_key);
      ServerInfo.cryptlink_private_key = NULL;

      yyerror("Ignoring rsa_cryptlink_key_file -- need at least a 1024 bit key size");
    }
  }
#endif
}
break;
case 78:
#line 729 "ircd_parser.y"
	{
  /* this isn't rehashable */
  if (ypass == 2)
  {
    if (ServerInfo.name == NULL)
    {
      /* the ircd will exit() in main() if we dont set one */
      if (strlen(yylval.string) <= HOSTLEN)
        DupString(ServerInfo.name, yylval.string);
    }
  }
}
break;
case 79:
#line 743 "ircd_parser.y"
	{
  /* this isn't rehashable */
  if (ypass == 2 && !ServerInfo.sid)
  {
    if (valid_sid(yylval.string))
      DupString(ServerInfo.sid, yylval.string);
    else
    {
      ilog(L_ERROR, "Ignoring config file entry SID -- invalid SID. Aborting.");
      exit(0);
    }
  }
}
break;
case 80:
#line 758 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ServerInfo.description);
    DupString(ServerInfo.description,yylval.string);
  }
}
break;
case 81:
#line 767 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    char *p;

    if ((p = strchr(yylval.string, ' ')) != NULL)
      p = '\0';

    MyFree(ServerInfo.network_name);
    DupString(ServerInfo.network_name, yylval.string);
  }
}
break;
case 82:
#line 781 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ServerInfo.network_desc);
    DupString(ServerInfo.network_desc, yylval.string);
  }
}
break;
case 83:
#line 790 "ircd_parser.y"
	{
  if (ypass == 2 && *yylval.string != '*')
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&ServerInfo.ip, res->ai_addr, res->ai_addrlen);
      ServerInfo.ip.ss.ss_family = res->ai_family;
      ServerInfo.ip.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);

      ServerInfo.specific_ipv4_vhost = 1;
    }
  }
}
break;
case 84:
#line 818 "ircd_parser.y"
	{
#ifdef IPV6
  if (ypass == 2 && *yylval.string != '*')
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost6(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&ServerInfo.ip6, res->ai_addr, res->ai_addrlen);
      ServerInfo.ip6.ss.ss_family = res->ai_family;
      ServerInfo.ip6.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);

      ServerInfo.specific_ipv6_vhost = 1;
    }
  }
#endif
}
break;
case 85:
#line 848 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    recalc_fdlimit(NULL);

    if (yystack.l_mark[-1].number < MAXCLIENTS_MIN)
    {
      char buf[IRCD_BUFSIZE];
      ircsprintf(buf, "MAXCLIENTS too low, setting to %d", MAXCLIENTS_MIN);
      yyerror(buf);
    }
    else if (yystack.l_mark[-1].number > MAXCLIENTS_MAX)
    {
      char buf[IRCD_BUFSIZE];
      ircsprintf(buf, "MAXCLIENTS too high, setting to %d", MAXCLIENTS_MAX);
      yyerror(buf);
    }
    else
      ServerInfo.max_clients = yystack.l_mark[-1].number;
  }
}
break;
case 86:
#line 871 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
    {
      /* Don't become a hub if we have a lazylink active. */
      if (!ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL))
      {
        sendto_realops_flags(UMODE_ALL, L_ALL,
                             "Ignoring config file line hub=yes; "
                             "due to active LazyLink (%s)", uplink->name);
      }
      else
      {
        ServerInfo.hub = 1;
        uplink = NULL;
        delete_capability("HUB");
        add_capability("HUB", CAP_HUB, 1);
      }
    }
    else if (ServerInfo.hub)
    {
      dlink_node *ptr = NULL;

      ServerInfo.hub = 0;
      delete_capability("HUB");

      /* Don't become a leaf if we have a lazylink active. */
      DLINK_FOREACH(ptr, serv_list.head)
      {
        const struct Client *acptr = ptr->data;
        if (MyConnect(acptr) && IsCapable(acptr, CAP_LL))
        {
          sendto_realops_flags(UMODE_ALL, L_ALL,
                               "Ignoring config file line hub=no; "
                               "due to active LazyLink (%s)",
                               acptr->name);
          add_capability("HUB", CAP_HUB, 1);
          ServerInfo.hub = 1;
          break;
        }
      }
    }
  }
}
break;
case 94:
#line 927 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(AdminInfo.name);
    DupString(AdminInfo.name, yylval.string);
  }
}
break;
case 95:
#line 936 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(AdminInfo.email);
    DupString(AdminInfo.email, yylval.string);
  }
}
break;
case 96:
#line 945 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(AdminInfo.description);
    DupString(AdminInfo.description, yylval.string);
  }
}
break;
case 113:
#line 972 "ircd_parser.y"
	{
                        }
break;
case 114:
#line 976 "ircd_parser.y"
	{
                        }
break;
case 115:
#line 980 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.userlog, yylval.string,
            sizeof(ConfigLoggingEntry.userlog));
}
break;
case 116:
#line 987 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.failed_operlog, yylval.string,
            sizeof(ConfigLoggingEntry.failed_operlog));
}
break;
case 117:
#line 994 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.operlog, yylval.string,
            sizeof(ConfigLoggingEntry.operlog));
}
break;
case 118:
#line 1001 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.operspylog, yylval.string,
            sizeof(ConfigLoggingEntry.operspylog));
}
break;
case 119:
#line 1008 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.glinelog, yylval.string,
            sizeof(ConfigLoggingEntry.glinelog));
}
break;
case 120:
#line 1015 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.klinelog, yylval.string,
            sizeof(ConfigLoggingEntry.klinelog));
}
break;
case 121:
#line 1022 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.ioerrlog, yylval.string,
            sizeof(ConfigLoggingEntry.ioerrlog));
}
break;
case 122:
#line 1029 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.killlog, yylval.string,
            sizeof(ConfigLoggingEntry.killlog));
}
break;
case 123:
#line 1036 "ircd_parser.y"
	{ 
  if (ypass == 2)
    set_log_level(L_CRIT);
}
break;
case 124:
#line 1040 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_ERROR);
}
break;
case 125:
#line 1044 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_WARN);
}
break;
case 126:
#line 1048 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_NOTICE);
}
break;
case 127:
#line 1052 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_TRACE);
}
break;
case 128:
#line 1056 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_INFO);
}
break;
case 129:
#line 1060 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_DEBUG);
}
break;
case 130:
#line 1066 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigLoggingEntry.use_logging = yylval.number;
}
break;
case 131:
#line 1075 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(OPER_TYPE);
    yy_aconf = map_to_conf(yy_conf);
    SetConfEncrypted(yy_aconf); /* Yes, the default is encrypted */
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 132:
#line 1088 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;
    dlink_node *ptr;
    dlink_node *next_ptr;

    if (yy_aconf->user && yy_aconf->host)
      conf_add_class_to_conf(yy_conf, class_name);
    else
      delete_conf_item(yy_conf);

    /* Now, make sure there is a copy of the "base" given oper
     * block in each of the collected copies
     */

    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;
      yy_tmp = ptr->data;

      new_conf = make_conf_item(OPER_TYPE);
      new_aconf = (struct AccessItem *)map_to_conf(new_conf);

      new_aconf->flags = yy_aconf->flags;

      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      if (yy_tmp->user != NULL)
	DupString(new_aconf->user, yy_tmp->user);
      else
	DupString(new_aconf->user, "*");
      if (yy_tmp->host != NULL)
	DupString(new_aconf->host, yy_tmp->host);
      else
	DupString(new_aconf->host, "*");
      conf_add_class_to_conf(new_conf, class_name);
      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);

      new_aconf->port = yy_aconf->port;
#ifdef HAVE_LIBCRYPTO
      if (yy_aconf->rsa_public_key_file != NULL)
      {
        BIO *file;

        DupString(new_aconf->rsa_public_key_file,
		  yy_aconf->rsa_public_key_file);

        file = BIO_new_file(yy_aconf->rsa_public_key_file, "r");
        new_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, 
							   NULL, 0, NULL);
        (void)BIO_set_close(file, BIO_CLOSE);
        BIO_free(file);
      }
      if (yy_aconf->certfp != NULL)
      {
        new_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
        memcpy(new_aconf->certfp, yy_aconf->certfp, SHA_DIGEST_LENGTH);
      }
#endif

#ifdef HAVE_LIBCRYPTO
      if (yy_tmp->name && (yy_tmp->passwd || yy_aconf->rsa_public_key)
	  && yy_tmp->host)
#else
      if (yy_tmp->name && yy_tmp->passwd && yy_tmp->host)
#endif
      {
        conf_add_class_to_conf(new_conf, class_name);
	if (yy_tmp->name != NULL)
	  DupString(new_conf->name, yy_tmp->name);
      }

      dlinkDelete(&yy_tmp->node, &col_conf_list);
      free_collect_item(yy_tmp);
    }

    yy_conf = NULL;
    yy_aconf = NULL;


    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 162:
#line 1188 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > OPERNICKLEN)
      yylval.string[OPERNICKLEN] = '\0';

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 163:
#line 1200 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > OPERNICKLEN)
      yylval.string[OPERNICKLEN] = '\0';

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 164:
#line 1212 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;
    
    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      struct CollectItem *yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 165:
#line 1246 "ircd_parser.y"
	{
  if (ypass == 2)
  {
#ifdef HAVE_LIBCRYPTO
    char tmp[SHA_DIGEST_LENGTH];
    
    if(yy_aconf->certfp != NULL)
    {
      MyFree(yy_aconf->certfp);
      yy_aconf->certfp = NULL;
    }

    if(base16_decode(tmp, SHA_DIGEST_LENGTH, yylval.string, strlen(yylval.string)) != 0)
    {
      yyerror("Invalid client certificate fingerprint provided. Ignoring");
      break;
    }
    yy_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->certfp, tmp, SHA_DIGEST_LENGTH);
#endif
  }
}
break;
case 166:
#line 1270 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 167:
#line 1282 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfEncrypted(yy_aconf);
    else
      ClearConfEncrypted(yy_aconf);
  }
}
break;
case 168:
#line 1293 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    BIO *file;

    if (yy_aconf->rsa_public_key != NULL)
    {
      RSA_free(yy_aconf->rsa_public_key);
      yy_aconf->rsa_public_key = NULL;
    }

    if (yy_aconf->rsa_public_key_file != NULL)
    {
      MyFree(yy_aconf->rsa_public_key_file);
      yy_aconf->rsa_public_key_file = NULL;
    }

    DupString(yy_aconf->rsa_public_key_file, yylval.string);
    file = BIO_new_file(yylval.string, "r");

    if (file == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- file doesn't exist");
      break;
    }

    yy_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, NULL, 0, NULL);

    if (yy_aconf->rsa_public_key == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- Key invalid; check key syntax.");
      break;
    }

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);
  }
#endif /* HAVE_LIBCRYPTO */
}
break;
case 169:
#line 1335 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 170:
#line 1344 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes = 0;
}
break;
case 174:
#line 1351 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_BOTS;
}
break;
case 175:
#line 1355 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CCONN;
}
break;
case 176:
#line 1359 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_NOCTCP;
}
break;
case 177:
#line 1363 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_DEAF;
}
break;
case 178:
#line 1367 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_DEBUG;
}
break;
case 179:
#line 1371 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_FULL;
}
break;
case 180:
#line 1375 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SKILL;
}
break;
case 181:
#line 1379 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_NCHANGE;
}
break;
case 182:
#line 1383 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_REJ;
}
break;
case 183:
#line 1387 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_UNAUTH;
}
break;
case 184:
#line 1391 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SPY;
}
break;
case 185:
#line 1395 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_EXTERNAL;
}
break;
case 186:
#line 1399 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_OPERWALL;
}
break;
case 187:
#line 1403 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SERVNOTICE;
}
break;
case 188:
#line 1407 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_INVISIBLE;
}
break;
case 189:
#line 1411 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_WALLOP;
}
break;
case 190:
#line 1415 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SOFTCALLERID;
}
break;
case 191:
#line 1419 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CALLERID;
}
break;
case 192:
#line 1423 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_LOCOPS;
}
break;
case 193:
#line 1427 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_HIDECHANNELS;
}
break;
case 194:
#line 1431 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_FARCONNECT;
}
break;
case 195:
#line 1437 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_GLOBAL_KILL;
    else
      yy_aconf->port &= ~OPER_FLAG_GLOBAL_KILL;
  }
}
break;
case 196:
#line 1448 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REMOTE;
    else
      yy_aconf->port &= ~OPER_FLAG_REMOTE; 
  }
}
break;
case 197:
#line 1459 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REMOTEBAN;
    else
      yy_aconf->port &= ~OPER_FLAG_REMOTEBAN;
  }
}
break;
case 198:
#line 1470 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_K;
    else
      yy_aconf->port &= ~OPER_FLAG_K;
  }
}
break;
case 199:
#line 1481 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_X;
    else
      yy_aconf->port &= ~OPER_FLAG_X;
  }
}
break;
case 200:
#line 1492 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_UNKLINE;
    else
      yy_aconf->port &= ~OPER_FLAG_UNKLINE; 
  }
}
break;
case 201:
#line 1503 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_GLINE;
    else
      yy_aconf->port &= ~OPER_FLAG_GLINE;
  }
}
break;
case 202:
#line 1514 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_N;
    else
      yy_aconf->port &= ~OPER_FLAG_N;
  }
}
break;
case 203:
#line 1525 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_DIE;
    else
      yy_aconf->port &= ~OPER_FLAG_DIE;
  }
}
break;
case 204:
#line 1536 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REHASH;
    else
      yy_aconf->port &= ~OPER_FLAG_REHASH;
  }
}
break;
case 205:
#line 1547 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_ADMIN;
    else
      yy_aconf->port &= ~OPER_FLAG_ADMIN;
  }
}
break;
case 206:
#line 1558 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_HIDDEN_ADMIN;
    else
      yy_aconf->port &= ~OPER_FLAG_HIDDEN_ADMIN;
  }
}
break;
case 207:
#line 1569 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_HIDDEN_OPER;
    else
      yy_aconf->port &= ~OPER_FLAG_HIDDEN_OPER;
  }
}
break;
case 208:
#line 1580 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_OPER_SPY;
    else
      yy_aconf->port &= ~OPER_FLAG_OPER_SPY;
  }
}
break;
case 209:
#line 1591 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_OPERWALL;
    else
      yy_aconf->port &= ~OPER_FLAG_OPERWALL;
  }
}
break;
case 210:
#line 1602 "ircd_parser.y"
	{
}
break;
case 214:
#line 1606 "ircd_parser.y"
	{ not_atom = 1; }
break;
case 216:
#line 1607 "ircd_parser.y"
	{ not_atom = 0; }
break;
case 218:
#line 1610 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)yy_aconf->port &= ~OPER_FLAG_GLOBAL_KILL;
    else yy_aconf->port |= OPER_FLAG_GLOBAL_KILL;
  }
}
break;
case 219:
#line 1617 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REMOTE;
    else yy_aconf->port |= OPER_FLAG_REMOTE;
  }
}
break;
case 220:
#line 1624 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_K;
    else yy_aconf->port |= OPER_FLAG_K;
  }
}
break;
case 221:
#line 1631 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_UNKLINE;
    else yy_aconf->port |= OPER_FLAG_UNKLINE;
  } 
}
break;
case 222:
#line 1638 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_X;
    else yy_aconf->port |= OPER_FLAG_X;
  }
}
break;
case 223:
#line 1645 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_GLINE;
    else yy_aconf->port |= OPER_FLAG_GLINE;
  }
}
break;
case 224:
#line 1652 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_DIE;
    else yy_aconf->port |= OPER_FLAG_DIE;
  }
}
break;
case 225:
#line 1659 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REHASH;
    else yy_aconf->port |= OPER_FLAG_REHASH;
  }
}
break;
case 226:
#line 1666 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_ADMIN;
    else yy_aconf->port |= OPER_FLAG_ADMIN;
  }
}
break;
case 227:
#line 1673 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_HIDDEN_ADMIN;
    else yy_aconf->port |= OPER_FLAG_HIDDEN_ADMIN;
  }
}
break;
case 228:
#line 1680 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_N;
    else yy_aconf->port |= OPER_FLAG_N;
  }
}
break;
case 229:
#line 1687 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_OPERWALL;
    else yy_aconf->port |= OPER_FLAG_OPERWALL;
  }
}
break;
case 230:
#line 1694 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_OPER_SPY;
    else yy_aconf->port |= OPER_FLAG_OPER_SPY;
  }
}
break;
case 231:
#line 1701 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_HIDDEN_OPER;
    else yy_aconf->port |= OPER_FLAG_HIDDEN_OPER;
  }
}
break;
case 232:
#line 1708 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REMOTEBAN;
    else yy_aconf->port |= OPER_FLAG_REMOTEBAN;
  }
}
break;
case 233:
#line 1715 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) ClearConfEncrypted(yy_aconf);
    else SetConfEncrypted(yy_aconf);
  }
}
break;
case 234:
#line 1722 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_FARCONNECT;
    else yy_aconf->port |= OPER_FLAG_FARCONNECT;
  }
}
break;
case 235:
#line 1735 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    yy_conf = make_conf_item(CLASS_TYPE);
    yy_class = map_to_conf(yy_conf);
  }
}
break;
case 236:
#line 1742 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    struct ConfItem *cconf = NULL;
    struct ClassItem *class = NULL;

    if (yy_class_name == NULL)
      delete_conf_item(yy_conf);
    else
    {
      cconf = find_exact_name_conf(CLASS_TYPE, yy_class_name, NULL, NULL, NULL);

      if (cconf != NULL)		/* The class existed already */
      {
        int user_count = 0;

        rebuild_cidr_class(cconf, yy_class);

        class = map_to_conf(cconf);

        user_count = class->curr_user_count;
        memcpy(class, yy_class, sizeof(*class));
        class->curr_user_count = user_count;
        class->active = 1;

        delete_conf_item(yy_conf);

        MyFree(cconf->name);            /* Allows case change of class name */
        cconf->name = yy_class_name;
      }
      else	/* Brand new class */
      {
        MyFree(yy_conf->name);          /* just in case it was allocated */
        yy_conf->name = yy_class_name;
	yy_class->active = 1;
      }
    }
    yy_class_name = NULL;
  }
}
break;
case 255:
#line 1801 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    MyFree(yy_class_name);
    DupString(yy_class_name, yylval.string);
  }
}
break;
case 256:
#line 1810 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    MyFree(yy_class_name);
    DupString(yy_class_name, yylval.string);
  }
}
break;
case 257:
#line 1819 "ircd_parser.y"
	{
  if (ypass == 1)
    PingFreq(yy_class) = yystack.l_mark[-1].number;
}
break;
case 258:
#line 1825 "ircd_parser.y"
	{
  if (ypass == 1)
    PingWarning(yy_class) = yystack.l_mark[-1].number;
}
break;
case 259:
#line 1831 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxPerIp(yy_class) = yystack.l_mark[-1].number;
}
break;
case 260:
#line 1837 "ircd_parser.y"
	{
  if (ypass == 1)
    ConFreq(yy_class) = yystack.l_mark[-1].number;
}
break;
case 261:
#line 1843 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxTotal(yy_class) = yystack.l_mark[-1].number;
}
break;
case 262:
#line 1849 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxGlobal(yy_class) = yystack.l_mark[-1].number;
}
break;
case 263:
#line 1855 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxLocal(yy_class) = yystack.l_mark[-1].number;
}
break;
case 264:
#line 1861 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxIdent(yy_class) = yystack.l_mark[-1].number;
}
break;
case 265:
#line 1867 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxSendq(yy_class) = yystack.l_mark[-1].number;
}
break;
case 266:
#line 1873 "ircd_parser.y"
	{
  if (ypass == 1)
    CidrBitlenIPV4(yy_class) = yystack.l_mark[-1].number;
}
break;
case 267:
#line 1879 "ircd_parser.y"
	{
  if (ypass == 1)
    CidrBitlenIPV6(yy_class) = yystack.l_mark[-1].number;
}
break;
case 268:
#line 1885 "ircd_parser.y"
	{
  if (ypass == 1)
    NumberPerCidr(yy_class) = yystack.l_mark[-1].number;
}
break;
case 269:
#line 1894 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    listener_address = NULL;
    listener_flags = 0;
  }
}
break;
case 270:
#line 1901 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(listener_address);
    listener_address = NULL;
  }
}
break;
case 271:
#line 1910 "ircd_parser.y"
	{
  listener_flags = 0;
}
break;
case 275:
#line 1916 "ircd_parser.y"
	{
  if (ypass == 2)
    listener_flags |= LISTENER_SSL;
}
break;
case 276:
#line 1920 "ircd_parser.y"
	{
  if (ypass == 2)
    listener_flags |= LISTENER_HIDDEN;
}
break;
case 284:
#line 1928 "ircd_parser.y"
	{ listener_flags = 0; }
break;
case 288:
#line 1933 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if ((listener_flags & LISTENER_SSL))
#ifdef HAVE_LIBCRYPTO
      if (!ServerInfo.ctx)
#endif
      {
        yyerror("SSL not available - port closed");
	break;
      }
    add_listener(yystack.l_mark[0].number, listener_address, listener_flags);
  }
}
break;
case 289:
#line 1947 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    int i;

    if ((listener_flags & LISTENER_SSL))
#ifdef HAVE_LIBCRYPTO
      if (!ServerInfo.ctx)
#endif
      {
        yyerror("SSL not available - port closed");
	break;
      }

    for (i = yystack.l_mark[-2].number; i <= yystack.l_mark[0].number; ++i)
      add_listener(i, listener_address, listener_flags);
  }
}
break;
case 290:
#line 1967 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(listener_address);
    DupString(listener_address, yylval.string);
  }
}
break;
case 291:
#line 1976 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(listener_address);
    DupString(listener_address, yylval.string);
  }
}
break;
case 292:
#line 1988 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(CLIENT_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 293:
#line 2000 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    dlink_node *ptr = NULL, *next_ptr = NULL;

    if (yy_aconf->user && yy_aconf->host)
    {
      conf_add_class_to_conf(yy_conf, class_name);
      add_conf_by_address(CONF_CLIENT, yy_aconf);
    }
    else
      delete_conf_item(yy_conf);

    /* copy over settings from first struct */
    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;

      new_conf = make_conf_item(CLIENT_TYPE);
      new_aconf = map_to_conf(new_conf);

      yy_tmp = ptr->data;

      assert(yy_tmp->user && yy_tmp->host);

      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);
      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);

      new_aconf->flags = yy_aconf->flags;
      new_aconf->port  = yy_aconf->port;

      DupString(new_aconf->user, yy_tmp->user);
      collapse(new_aconf->user);

      DupString(new_aconf->host, yy_tmp->host);
      collapse(new_aconf->host);

#ifdef HAVE_LIBCRYPTO
      if (yy_aconf->certfp != NULL)
      {
        new_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
        memcpy(new_aconf->certfp, yy_aconf->certfp, SHA_DIGEST_LENGTH);
      }
#endif

      conf_add_class_to_conf(new_conf, class_name);
      add_conf_by_address(CONF_CLIENT, new_aconf);
      dlinkDelete(&yy_tmp->node, &col_conf_list);
      free_collect_item(yy_tmp);
    }

    MyFree(class_name);
    class_name = NULL;
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 315:
#line 2073 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 316:
#line 2110 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    /* be paranoid */
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 317:
#line 2123 "ircd_parser.y"
	{
  if (ypass == 2)
  {
#ifdef HAVE_LIBCRYPTO
    char tmp[SHA_DIGEST_LENGTH];

    if(yy_aconf->certfp != NULL)
    {
      MyFree(yy_aconf->certfp);
      yy_aconf->certfp = NULL;
    }

    if(base16_decode(tmp, SHA_DIGEST_LENGTH, yylval.string, strlen(yylval.string)) != 0)
    {
      yyerror("Invalid client certificate fingerprint provided. Ignoring");
      break;
    }
    yy_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->certfp, tmp, SHA_DIGEST_LENGTH);
#endif
  }
}
break;
case 318:
#line 2147 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_SPOOF_NOTICE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_SPOOF_NOTICE;
  }
}
break;
case 319:
#line 2158 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 320:
#line 2167 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfEncrypted(yy_aconf);
    else
      ClearConfEncrypted(yy_aconf);
  }
}
break;
case 321:
#line 2178 "ircd_parser.y"
	{
}
break;
case 325:
#line 2182 "ircd_parser.y"
	{ not_atom = 1; }
break;
case 327:
#line 2183 "ircd_parser.y"
	{ not_atom = 0; }
break;
case 329:
#line 2186 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_SPOOF_NOTICE;
    else yy_aconf->flags |= CONF_FLAGS_SPOOF_NOTICE;
  }

}
break;
case 330:
#line 2194 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NOLIMIT;
    else yy_aconf->flags |= CONF_FLAGS_NOLIMIT;
  }
}
break;
case 331:
#line 2201 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTKLINE;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTKLINE;
  } 
}
break;
case 332:
#line 2208 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NEED_IDENTD;
    else yy_aconf->flags |= CONF_FLAGS_NEED_IDENTD;
  }
}
break;
case 333:
#line 2215 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_CAN_FLOOD;
    else yy_aconf->flags |= CONF_FLAGS_CAN_FLOOD;
  }
}
break;
case 334:
#line 2222 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_IDLE_LINED;
    else yy_aconf->flags |= CONF_FLAGS_IDLE_LINED;
  }
}
break;
case 335:
#line 2229 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NO_TILDE;
    else yy_aconf->flags |= CONF_FLAGS_NO_TILDE;
  } 
}
break;
case 336:
#line 2236 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTGLINE;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTGLINE;
  } 
}
break;
case 337:
#line 2243 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTRESV;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTRESV;
  }
}
break;
case 338:
#line 2250 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_WEBIRC;
    else yy_aconf->flags |= CONF_FLAGS_WEBIRC;
  }
}
break;
case 339:
#line 2257 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NEED_PASSWORD;
    else yy_aconf->flags |= CONF_FLAGS_NEED_PASSWORD;
  }
}
break;
case 340:
#line 2266 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_EXEMPTKLINE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_EXEMPTKLINE;
  }
}
break;
case 341:
#line 2277 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NEED_IDENTD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NEED_IDENTD;
  }
}
break;
case 342:
#line 2288 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NOLIMIT;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NOLIMIT;
  }
}
break;
case 343:
#line 2299 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_CAN_FLOOD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_CAN_FLOOD;
  }
}
break;
case 344:
#line 2310 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NO_TILDE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NO_TILDE;
  }
}
break;
case 345:
#line 2321 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_EXEMPTGLINE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_EXEMPTGLINE;
  }
}
break;
case 346:
#line 2333 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);

    if (strlen(yylval.string) < HOSTLEN)
    {    
      DupString(yy_conf->name, yylval.string);
      yy_aconf->flags |= CONF_FLAGS_SPOOF_IP;
    }
    else
    {
      ilog(L_ERROR, "Spoofs must be less than %d..ignoring it", HOSTLEN);
      yy_conf->name = NULL;
    }
  }
}
break;
case 347:
#line 2352 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_aconf->flags |= CONF_FLAGS_REDIR;
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 348:
#line 2362 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_aconf->flags |= CONF_FLAGS_REDIR;
    yy_aconf->port = yystack.l_mark[-1].number;
  }
}
break;
case 349:
#line 2371 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_WEBIRC;
    else
      yy_aconf->flags &= ~CONF_FLAGS_WEBIRC;
  }
}
break;
case 350:
#line 2382 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NEED_PASSWORD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NEED_PASSWORD;
  }
}
break;
case 351:
#line 2397 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    resv_reason = NULL;
  }
}
break;
case 352:
#line 2404 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    resv_reason = NULL;
  }
}
break;
case 359:
#line 2416 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    DupString(resv_reason, yylval.string);
  }
}
break;
case 360:
#line 2425 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (IsChanPrefix(*yylval.string))
    {
      char def_reason[] = "No reason";

      create_channel_resv(yylval.string, resv_reason != NULL ? resv_reason : def_reason, 1);
    }
  }
  /* ignore it for now.. but we really should make a warning if
   * its an erroneous name --fl_ */
}
break;
case 361:
#line 2440 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    char def_reason[] = "No reason";

    create_nick_resv(yylval.string, resv_reason != NULL ? resv_reason : def_reason, 1);
  }
}
break;
case 362:
#line 2453 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(ULINE_TYPE);
    yy_match_item = map_to_conf(yy_conf);
    yy_match_item->action = SHARED_ALL;
  }
}
break;
case 363:
#line 2461 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = NULL;
  }
}
break;
case 370:
#line 2472 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 371:
#line 2481 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    DupString(yy_match_item->user, userbuf);
    DupString(yy_match_item->host, hostbuf);
  }
}
break;
case 372:
#line 2503 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action = 0;
}
break;
case 376:
#line 2510 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_KLINE;
}
break;
case 377:
#line 2514 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TKLINE;
}
break;
case 378:
#line 2518 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNKLINE;
}
break;
case 379:
#line 2522 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_XLINE;
}
break;
case 380:
#line 2526 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TXLINE;
}
break;
case 381:
#line 2530 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNXLINE;
}
break;
case 382:
#line 2534 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_RESV;
}
break;
case 383:
#line 2538 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TRESV;
}
break;
case 384:
#line 2542 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNRESV;
}
break;
case 385:
#line 2546 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_LOCOPS;
}
break;
case 386:
#line 2550 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_SERVICES;
}
break;
case 387:
#line 2554 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_REHASH;
}
break;
case 388:
#line 2558 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action = SHARED_ALL;
}
break;
case 389:
#line 2567 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(CLUSTER_TYPE);
    yy_conf->flags = SHARED_ALL;
  }
}
break;
case 390:
#line 2574 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_conf->name == NULL)
      DupString(yy_conf->name, "*");
    yy_conf = NULL;
  }
}
break;
case 396:
#line 2587 "ircd_parser.y"
	{
  if (ypass == 2)
    DupString(yy_conf->name, yylval.string);
}
break;
case 397:
#line 2593 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags = 0;
}
break;
case 401:
#line 2600 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_KLINE;
}
break;
case 402:
#line 2604 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TKLINE;
}
break;
case 403:
#line 2608 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNKLINE;
}
break;
case 404:
#line 2612 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_XLINE;
}
break;
case 405:
#line 2616 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TXLINE;
}
break;
case 406:
#line 2620 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNXLINE;
}
break;
case 407:
#line 2624 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_RESV;
}
break;
case 408:
#line 2628 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TRESV;
}
break;
case 409:
#line 2632 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNRESV;
}
break;
case 410:
#line 2636 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_LOCOPS;
}
break;
case 411:
#line 2640 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags = SHARED_ALL;
}
break;
case 412:
#line 2649 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(SERVER_TYPE);
    yy_aconf = (struct AccessItem *)map_to_conf(yy_conf);
    yy_aconf->passwd = NULL;
    /* defaults */
    yy_aconf->port = PORTNUM;

    if (ConfigFileEntry.burst_away)
      yy_aconf->flags = CONF_FLAGS_BURST_AWAY;
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 413:
#line 2667 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_hconf=NULL;
    struct CollectItem *yy_lconf=NULL;
    dlink_node *ptr;
    dlink_node *next_ptr;
#ifdef HAVE_LIBCRYPTO
    if (yy_aconf->host &&
	((yy_aconf->passwd && yy_aconf->spasswd) ||
	 (yy_aconf->rsa_public_key && IsConfCryptLink(yy_aconf))))
#else /* !HAVE_LIBCRYPTO */
      if (yy_aconf->host && !IsConfCryptLink(yy_aconf) && 
	  yy_aconf->passwd && yy_aconf->spasswd)
#endif /* !HAVE_LIBCRYPTO */
	{
	  if (conf_add_server(yy_conf, class_name) == -1)
	  {
	    delete_conf_item(yy_conf);
	    yy_conf = NULL;
	    yy_aconf = NULL;
	  }
	}
	else
	{
	  /* Even if yy_conf ->name is NULL
	   * should still unhook any hub/leaf confs still pending
	   */
	  unhook_hub_leaf_confs();

	  if (yy_conf->name != NULL)
	  {
#ifndef HAVE_LIBCRYPTO
	    if (IsConfCryptLink(yy_aconf))
	      yyerror("Ignoring connect block -- no OpenSSL support");
#else
	    if (IsConfCryptLink(yy_aconf) && !yy_aconf->rsa_public_key)
	      yyerror("Ignoring connect block -- missing key");
#endif
	    if (yy_aconf->host == NULL)
	      yyerror("Ignoring connect block -- missing host");
	    else if (!IsConfCryptLink(yy_aconf) && 
		    (!yy_aconf->passwd || !yy_aconf->spasswd))
              yyerror("Ignoring connect block -- missing password");
	  }


          /* XXX
           * This fixes a try_connections() core (caused by invalid class_ptr
           * pointers) reported by metalrock. That's an ugly fix, but there
           * is currently no better way. The entire config subsystem needs an
           * rewrite ASAP. make_conf_item() shouldn't really add things onto
           * a doubly linked list immediately without any sanity checks!  -Michael
           */
          delete_conf_item(yy_conf);

          yy_aconf = NULL;
	  yy_conf = NULL;
	}

      /*
       * yy_conf is still pointing at the server that is having
       * a connect block built for it. This means, y_aconf->name 
       * points to the actual irc name this server will be known as.
       * Now this new server has a set or even just one hub_mask (or leaf_mask)
       * given in the link list at yy_hconf. Fill in the HUB confs
       * from this link list now.
       */        
      DLINK_FOREACH_SAFE(ptr, next_ptr, hub_conf_list.head)
      {
	struct ConfItem *new_hub_conf;
	struct MatchItem *match_item;

	yy_hconf = ptr->data;

	/* yy_conf == NULL is a fatal error for this connect block! */
	if ((yy_conf != NULL) && (yy_conf->name != NULL))
	{
	  new_hub_conf = make_conf_item(HUB_TYPE);
	  match_item = (struct MatchItem *)map_to_conf(new_hub_conf);
	  DupString(new_hub_conf->name, yy_conf->name);
	  if (yy_hconf->user != NULL)
	    DupString(match_item->user, yy_hconf->user);
	  else
	    DupString(match_item->user, "*");
	  if (yy_hconf->host != NULL)
	    DupString(match_item->host, yy_hconf->host);
	  else
	    DupString(match_item->host, "*");
	}
	dlinkDelete(&yy_hconf->node, &hub_conf_list);
	free_collect_item(yy_hconf);
      }

      /* Ditto for the LEAF confs */

      DLINK_FOREACH_SAFE(ptr, next_ptr, leaf_conf_list.head)
      {
	struct ConfItem *new_leaf_conf;
	struct MatchItem *match_item;

	yy_lconf = ptr->data;

	if ((yy_conf != NULL) && (yy_conf->name != NULL))
	{
	  new_leaf_conf = make_conf_item(LEAF_TYPE);
	  match_item = (struct MatchItem *)map_to_conf(new_leaf_conf);
	  DupString(new_leaf_conf->name, yy_conf->name);
	  if (yy_lconf->user != NULL)
	    DupString(match_item->user, yy_lconf->user);
	  else
	    DupString(match_item->user, "*");
	  if (yy_lconf->host != NULL)
	    DupString(match_item->host, yy_lconf->host);
	  else
	    DupString(match_item->host, "*");
	}
	dlinkDelete(&yy_lconf->node, &leaf_conf_list);
	free_collect_item(yy_lconf);
      }
      MyFree(class_name);
      class_name = NULL;
      yy_conf = NULL;
      yy_aconf = NULL;
  }
}
break;
case 438:
#line 2806 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_conf->name != NULL)
      yyerror("Multiple connect name entry");

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 439:
#line 2818 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_conf->name != NULL)
      yyerror("Multiple connect name entry");

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 440:
#line 2830 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 441:
#line 2839 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&yy_aconf->my_ipnum, res->ai_addr, res->ai_addrlen);
      yy_aconf->my_ipnum.ss.ss_family = res->ai_family;
      yy_aconf->my_ipnum.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);
    }
  }
}
break;
case 442:
#line 2865 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yystack.l_mark[-1].string[0] == ':')
      yyerror("Server passwords cannot begin with a colon");
    else if (strchr(yystack.l_mark[-1].string, ' ') != NULL)
      yyerror("Server passwords cannot contain spaces");
    else {
      if (yy_aconf->spasswd != NULL)
        memset(yy_aconf->spasswd, 0, strlen(yy_aconf->spasswd));

      MyFree(yy_aconf->spasswd);
      DupString(yy_aconf->spasswd, yylval.string);
    }
  }
}
break;
case 443:
#line 2883 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yystack.l_mark[-1].string[0] == ':')
      yyerror("Server passwords cannot begin with a colon");
    else if (strchr(yystack.l_mark[-1].string, ' ') != NULL)
      yyerror("Server passwords cannot contain spaces");
    else {
      if (yy_aconf->passwd != NULL)
        memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

      MyFree(yy_aconf->passwd);
      DupString(yy_aconf->passwd, yylval.string);
    }
  }
}
break;
case 444:
#line 2901 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->port = yystack.l_mark[-1].number;
}
break;
case 445:
#line 2907 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->aftype = AF_INET;
}
break;
case 446:
#line 2911 "ircd_parser.y"
	{
#ifdef IPV6
  if (ypass == 2)
    yy_aconf->aftype = AF_INET6;
#endif
}
break;
case 447:
#line 2919 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->fakename);
    DupString(yy_aconf->fakename, yylval.string);
  }
}
break;
case 448:
#line 2928 "ircd_parser.y"
	{
}
break;
case 452:
#line 2932 "ircd_parser.y"
	{ not_atom = 1; }
break;
case 454:
#line 2933 "ircd_parser.y"
	{ not_atom = 0; }
break;
case 456:
#line 2936 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfLazyLink(yy_aconf);
    else SetConfLazyLink(yy_aconf);
  }
}
break;
case 457:
#line 2943 "ircd_parser.y"
	{
  if (ypass == 2)
#ifndef HAVE_LIBZ
    yyerror("Ignoring flags = compressed; -- no zlib support");
#else
 {
   if (not_atom)ClearConfCompressed(yy_aconf);
   else SetConfCompressed(yy_aconf);
 }
#endif
}
break;
case 458:
#line 2954 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfCryptLink(yy_aconf);
    else SetConfCryptLink(yy_aconf);
  }
}
break;
case 459:
#line 2961 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfAllowAutoConn(yy_aconf);
    else SetConfAllowAutoConn(yy_aconf);
  }
}
break;
case 460:
#line 2968 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfAwayBurst(yy_aconf);
    else SetConfAwayBurst(yy_aconf);
  }
}
break;
case 461:
#line 2975 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfTopicBurst(yy_aconf);
    else SetConfTopicBurst(yy_aconf);
  }
}
break;
case 462:
#line 2985 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    BIO *file;

    if (yy_aconf->rsa_public_key != NULL)
    {
      RSA_free(yy_aconf->rsa_public_key);
      yy_aconf->rsa_public_key = NULL;
    }

    if (yy_aconf->rsa_public_key_file != NULL)
    {
      MyFree(yy_aconf->rsa_public_key_file);
      yy_aconf->rsa_public_key_file = NULL;
    }

    DupString(yy_aconf->rsa_public_key_file, yylval.string);

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- file doesn't exist");
      break;
    }

    yy_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, NULL, 0, NULL);

    if (yy_aconf->rsa_public_key == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- Key invalid; check key syntax.");
      break;
    }

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);
  }
#endif /* HAVE_LIBCRYPTO */
}
break;
case 463:
#line 3026 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_ENCRYPTED;
    else
      yy_aconf->flags &= ~CONF_FLAGS_ENCRYPTED;
  }
}
break;
case 464:
#line 3037 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_CRYPTLINK;
    else
      yy_aconf->flags &= ~CONF_FLAGS_CRYPTLINK;
  }
}
break;
case 465:
#line 3048 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
#ifndef HAVE_LIBZ
      yyerror("Ignoring compressed=yes; -- no zlib support");
#else
      yy_aconf->flags |= CONF_FLAGS_COMPRESSED;
#endif
    else
      yy_aconf->flags &= ~CONF_FLAGS_COMPRESSED;
  }
}
break;
case 466:
#line 3063 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_ALLOW_AUTO_CONN;
    else
      yy_aconf->flags &= ~CONF_FLAGS_ALLOW_AUTO_CONN;
  }
}
break;
case 467:
#line 3074 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfTopicBurst(yy_aconf);
    else
      ClearConfTopicBurst(yy_aconf);
  }
}
break;
case 468:
#line 3085 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;

    yy_tmp = (struct CollectItem *)MyMalloc(sizeof(struct CollectItem));
    DupString(yy_tmp->host, yylval.string);
    DupString(yy_tmp->user, "*");
    dlinkAdd(yy_tmp, &yy_tmp->node, &hub_conf_list);
  }
}
break;
case 469:
#line 3098 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;

    yy_tmp = (struct CollectItem *)MyMalloc(sizeof(struct CollectItem));
    DupString(yy_tmp->host, yylval.string);
    DupString(yy_tmp->user, "*");
    dlinkAdd(yy_tmp, &yy_tmp->node, &leaf_conf_list);
  }
}
break;
case 470:
#line 3111 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 471:
#line 3120 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    struct EncCapability *ecap;
    const char *cipher_name;
    int found = 0;

    yy_aconf->cipher_preference = NULL;
    cipher_name = yylval.string;

    for (ecap = CipherTable; ecap->name; ecap++)
    {
      if ((irccmp(ecap->name, cipher_name) == 0) &&
          (ecap->cap & CAP_ENC_MASK))
      {
        yy_aconf->cipher_preference = ecap;
        found = 1;
        break;
      }
    }

    if (!found)
      yyerror("Invalid cipher");
  }
#else
  if (ypass == 2)
    yyerror("Ignoring cipher_preference -- no OpenSSL support");
#endif
}
break;
case 472:
#line 3155 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    userbuf[0] = hostbuf[0] = reasonbuf[0] = '\0';
    regex_ban = 0;
  }
}
break;
case 473:
#line 3162 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (userbuf[0] && hostbuf[0])
    {
      if (regex_ban)
      {
        pcre *exp_user = NULL;
        pcre *exp_host = NULL;
        const char *errptr = NULL;

        if (!(exp_user = ircd_pcre_compile(userbuf, &errptr)) ||
            !(exp_host = ircd_pcre_compile(hostbuf, &errptr)))
        {
          ilog(L_ERROR, "Failed to add regular expression based K-Line: %s", errptr);
          break;
        }

        yy_conf = make_conf_item(RKLINE_TYPE);
	yy_aconf = map_to_conf(yy_conf);

        yy_aconf->regexuser = exp_user;
        yy_aconf->regexhost = exp_host;

        DupString(yy_aconf->user, userbuf);
        DupString(yy_aconf->host, hostbuf);

        if (reasonbuf[0])
          DupString(yy_aconf->reason, reasonbuf);
        else
          DupString(yy_aconf->reason, "No reason");
      }
      else
      {
        yy_conf = make_conf_item(KLINE_TYPE);
        yy_aconf = map_to_conf(yy_conf);

        DupString(yy_aconf->user, userbuf);
        DupString(yy_aconf->host, hostbuf);

        if (reasonbuf[0])
          DupString(yy_aconf->reason, reasonbuf);
        else
          DupString(yy_aconf->reason, "No reason");
        add_conf_by_address(CONF_KILL, yy_aconf);
      }
    }
    else
      delete_conf_item(yy_conf);

    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 474:
#line 3218 "ircd_parser.y"
	{
}
break;
case 478:
#line 3223 "ircd_parser.y"
	{
  if (ypass == 2)
    regex_ban = 1;
}
break;
case 485:
#line 3232 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);
  }
}
break;
case 486:
#line 3251 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(reasonbuf, yylval.string, sizeof(reasonbuf));
}
break;
case 487:
#line 3260 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(DLINE_TYPE);
    yy_aconf = map_to_conf(yy_conf);
    /* default reason */
    DupString(yy_aconf->reason, "No reason");
  }
}
break;
case 488:
#line 3269 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_aconf->host && parse_netmask(yy_aconf->host, NULL, NULL) != HM_HOST)
      add_conf_by_address(CONF_DLINE, yy_aconf);
    else
      delete_conf_item(yy_conf);
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 494:
#line 3285 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 495:
#line 3294 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->reason);
    DupString(yy_aconf->reason, yylval.string);
  }
}
break;
case 502:
#line 3311 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.string[0] && parse_netmask(yylval.string, NULL, NULL) != HM_HOST)
    {
      yy_conf = make_conf_item(EXEMPTDLINE_TYPE);
      yy_aconf = map_to_conf(yy_conf);
      DupString(yy_aconf->host, yylval.string);

      add_conf_by_address(CONF_EXEMPTDLINE, yy_aconf);

      yy_conf = NULL;
      yy_aconf = NULL;
    }
  }
}
break;
case 503:
#line 3329 "ircd_parser.y"
	{
  if (ypass == 2)
  {
#ifdef HAVE_LIBCRYPTO
    char tmp[SHA_DIGEST_LENGTH];

    yy_conf = make_conf_item(EXEMPTDLINE_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  
    if(base16_decode(tmp, SHA_DIGEST_LENGTH, yylval.string, strlen(yylval.string)) != 0)
    {
      yyerror("Invalid client certificate fingerprint provided. Ignoring");
      break;
    }
 
    yy_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
    yy_aconf->host = MyMalloc(SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->certfp, tmp, SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->host, tmp, SHA_DIGEST_LENGTH);
 
    add_conf_by_address(CONF_EXEMPTDLINE, yy_aconf);

    yy_conf = NULL;
    yy_aconf = NULL;
#endif
 }
}
break;
case 504:
#line 3362 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    regex_ban = 0;
    reasonbuf[0] = gecos_name[0] = '\0';
  }
}
break;
case 505:
#line 3369 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (gecos_name[0])
    {
      if (regex_ban)
      {
        pcre *exp_p = NULL;
        const char *errptr = NULL;

        if (!(exp_p = ircd_pcre_compile(gecos_name, &errptr)))
        {
          ilog(L_ERROR, "Failed to add regular expression based X-Line: %s", errptr);
          break;
        }

        yy_conf = make_conf_item(RXLINE_TYPE);
        yy_conf->regexpname = exp_p;
      }
      else
        yy_conf = make_conf_item(XLINE_TYPE);

      yy_match_item = map_to_conf(yy_conf);
      DupString(yy_conf->name, gecos_name);

      if (reasonbuf[0])
        DupString(yy_match_item->reason, reasonbuf);
      else
        DupString(yy_match_item->reason, "No reason");
    }
  }
}
break;
case 506:
#line 3403 "ircd_parser.y"
	{
}
break;
case 510:
#line 3408 "ircd_parser.y"
	{
  if (ypass == 2)
    regex_ban = 1;
}
break;
case 517:
#line 3417 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(gecos_name, yylval.string, sizeof(gecos_name));
}
break;
case 518:
#line 3423 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(reasonbuf, yylval.string, sizeof(reasonbuf));
}
break;
case 588:
#line 3472 "ircd_parser.y"
	{
  ConfigFileEntry.gline_min_cidr = yystack.l_mark[-1].number;
}
break;
case 589:
#line 3477 "ircd_parser.y"
	{
  ConfigFileEntry.gline_min_cidr6 = yystack.l_mark[-1].number;
}
break;
case 590:
#line 3482 "ircd_parser.y"
	{
  ConfigFileEntry.burst_away = yylval.number;
}
break;
case 591:
#line 3487 "ircd_parser.y"
	{
  ConfigFileEntry.use_whois_actually = yylval.number;
}
break;
case 592:
#line 3492 "ircd_parser.y"
	{
  ConfigFileEntry.nick_collide_realhost = yylval.number;
}
break;
case 593:
#line 3497 "ircd_parser.y"
	{
  GlobalSetOptions.rejecttime = yylval.number;
}
break;
case 594:
#line 3502 "ircd_parser.y"
	{
  ConfigFileEntry.tkline_expire_notices = yylval.number;
}
break;
case 595:
#line 3507 "ircd_parser.y"
	{
  ConfigFileEntry.kill_chase_time_limit = yystack.l_mark[-1].number;
}
break;
case 596:
#line 3512 "ircd_parser.y"
	{
  ConfigFileEntry.hide_spoof_ips = yylval.number;
}
break;
case 597:
#line 3517 "ircd_parser.y"
	{
  ConfigFileEntry.ignore_bogus_ts = yylval.number;
}
break;
case 598:
#line 3522 "ircd_parser.y"
	{
  ConfigFileEntry.disable_remote = yylval.number;
}
break;
case 599:
#line 3527 "ircd_parser.y"
	{
  ConfigFileEntry.failed_oper_notice = yylval.number;
}
break;
case 600:
#line 3532 "ircd_parser.y"
	{
  ConfigFileEntry.anti_nick_flood = yylval.number;
}
break;
case 601:
#line 3537 "ircd_parser.y"
	{
  ConfigFileEntry.max_nick_time = yystack.l_mark[-1].number; 
}
break;
case 602:
#line 3542 "ircd_parser.y"
	{
  ConfigFileEntry.max_nick_changes = yystack.l_mark[-1].number;
}
break;
case 603:
#line 3547 "ircd_parser.y"
	{
  ConfigFileEntry.max_accept = yystack.l_mark[-1].number;
}
break;
case 604:
#line 3552 "ircd_parser.y"
	{
  ConfigFileEntry.anti_spam_exit_message_time = yystack.l_mark[-1].number;
}
break;
case 605:
#line 3557 "ircd_parser.y"
	{
  ConfigFileEntry.anti_spam_connect_numeric = yylval.number;
}
break;
case 606:
#line 3562 "ircd_parser.y"
	{
  ConfigFileEntry.ts_warn_delta = yystack.l_mark[-1].number;
}
break;
case 607:
#line 3567 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.ts_max_delta = yystack.l_mark[-1].number;
}
break;
case 608:
#line 3573 "ircd_parser.y"
	{
  if ((yystack.l_mark[-1].number > 0) && ypass == 1)
  {
    ilog(L_CRIT, "You haven't read your config file properly.");
    ilog(L_CRIT, "There is a line in the example conf that will kill your server if not removed.");
    ilog(L_CRIT, "Consider actually reading/editing the conf file, and removing this line.");
    exit(0);
  }
}
break;
case 609:
#line 3584 "ircd_parser.y"
	{
  ConfigFileEntry.kline_with_reason = yylval.number;
}
break;
case 610:
#line 3589 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.kline_reason);
    DupString(ConfigFileEntry.kline_reason, yylval.string);
  }
}
break;
case 611:
#line 3598 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.cloak_key1);
    DupString(ConfigFileEntry.cloak_key1, yylval.string);
  }
}
break;
case 612:
#line 3607 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.cloak_key2);
    DupString(ConfigFileEntry.cloak_key2, yylval.string);
  }
}
break;
case 613:
#line 3616 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.cloak_key3);
    DupString(ConfigFileEntry.cloak_key3, yylval.string);
  }
}
break;
case 614:
#line 3625 "ircd_parser.y"
	{
  ConfigFileEntry.cloak_whois_actually = yylval.number;
}
break;
case 615:
#line 3630 "ircd_parser.y"
	{
  ConfigFileEntry.account_whois = yylval.number;
}
break;
case 616:
#line 3635 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.services_name);
    DupString(ConfigFileEntry.services_name, yylval.string);
  }
}
break;
case 617:
#line 3644 "ircd_parser.y"
	{
  ConfigFileEntry.invisible_on_connect = yylval.number;
}
break;
case 618:
#line 3649 "ircd_parser.y"
	{
  ConfigFileEntry.warn_no_nline = yylval.number;
}
break;
case 619:
#line 3654 "ircd_parser.y"
	{
  ConfigFileEntry.stats_e_disabled = yylval.number;
}
break;
case 620:
#line 3659 "ircd_parser.y"
	{
  ConfigFileEntry.stats_o_oper_only = yylval.number;
}
break;
case 621:
#line 3664 "ircd_parser.y"
	{
  ConfigFileEntry.stats_P_oper_only = yylval.number;
}
break;
case 622:
#line 3669 "ircd_parser.y"
	{
  ConfigFileEntry.hide_killer = yylval.number;
}
break;
case 623:
#line 3674 "ircd_parser.y"
	{
  ConfigFileEntry.stats_k_oper_only = 2 * yylval.number;
}
break;
case 624:
#line 3677 "ircd_parser.y"
	{
  ConfigFileEntry.stats_k_oper_only = 1;
}
break;
case 625:
#line 3682 "ircd_parser.y"
	{
  ConfigFileEntry.stats_i_oper_only = 2 * yylval.number;
}
break;
case 626:
#line 3685 "ircd_parser.y"
	{
  ConfigFileEntry.stats_i_oper_only = 1;
}
break;
case 627:
#line 3690 "ircd_parser.y"
	{
  ConfigFileEntry.pace_wait = yystack.l_mark[-1].number;
}
break;
case 628:
#line 3695 "ircd_parser.y"
	{
  ConfigFileEntry.caller_id_wait = yystack.l_mark[-1].number;
}
break;
case 629:
#line 3700 "ircd_parser.y"
	{
  ConfigFileEntry.opers_bypass_callerid = yylval.number;
}
break;
case 630:
#line 3705 "ircd_parser.y"
	{
  ConfigFileEntry.pace_wait_simple = yystack.l_mark[-1].number;
}
break;
case 631:
#line 3710 "ircd_parser.y"
	{
  ConfigFileEntry.short_motd = yylval.number;
}
break;
case 632:
#line 3715 "ircd_parser.y"
	{
  ConfigFileEntry.no_oper_flood = yylval.number;
}
break;
case 633:
#line 3720 "ircd_parser.y"
	{
  ConfigFileEntry.true_no_oper_flood = yylval.number;
}
break;
case 634:
#line 3725 "ircd_parser.y"
	{
  ConfigFileEntry.oper_pass_resv = yylval.number;
}
break;
case 635:
#line 3730 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > LOCALE_LENGTH-2)
      yylval.string[LOCALE_LENGTH-1] = '\0';

    set_locale(yylval.string);
  }
}
break;
case 636:
#line 3741 "ircd_parser.y"
	{
  ConfigFileEntry.idletime = yystack.l_mark[-1].number;
}
break;
case 637:
#line 3746 "ircd_parser.y"
	{
  ConfigFileEntry.dots_in_ident = yystack.l_mark[-1].number;
}
break;
case 638:
#line 3751 "ircd_parser.y"
	{
  ConfigFileEntry.max_targets = yystack.l_mark[-1].number;
}
break;
case 639:
#line 3756 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.servlink_path);
    DupString(ConfigFileEntry.servlink_path, yylval.string);
  }
}
break;
case 640:
#line 3765 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    struct EncCapability *ecap;
    const char *cipher_name;
    int found = 0;

    ConfigFileEntry.default_cipher_preference = NULL;
    cipher_name = yylval.string;

    for (ecap = CipherTable; ecap->name; ecap++)
    {
      if ((irccmp(ecap->name, cipher_name) == 0) &&
          (ecap->cap & CAP_ENC_MASK))
      {
        ConfigFileEntry.default_cipher_preference = ecap;
        found = 1;
        break;
      }
    }

    if (!found)
      yyerror("Invalid cipher");
  }
#else
  if (ypass == 2)
    yyerror("Ignoring default_cipher_preference -- no OpenSSL support");
#endif
}
break;
case 641:
#line 3797 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    ConfigFileEntry.compression_level = yystack.l_mark[-1].number;
#ifndef HAVE_LIBZ
    yyerror("Ignoring compression_level -- no zlib support");
#else
    if ((ConfigFileEntry.compression_level < 1) ||
        (ConfigFileEntry.compression_level > 9))
    {
      yyerror("Ignoring invalid compression_level, using default");
      ConfigFileEntry.compression_level = 0;
    }
#endif
  }
}
break;
case 642:
#line 3815 "ircd_parser.y"
	{
  ConfigFileEntry.use_egd = yylval.number;
}
break;
case 643:
#line 3820 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.egdpool_path);
    DupString(ConfigFileEntry.egdpool_path, yylval.string);
  }
}
break;
case 644:
#line 3829 "ircd_parser.y"
	{
  ConfigFileEntry.ping_cookie = yylval.number;
}
break;
case 645:
#line 3834 "ircd_parser.y"
	{
  ConfigFileEntry.disable_auth = yylval.number;
}
break;
case 646:
#line 3839 "ircd_parser.y"
	{
  ConfigFileEntry.throttle_num = yylval.number;
}
break;
case 647:
#line 3844 "ircd_parser.y"
	{
  ConfigFileEntry.throttle_time = yylval.number;
}
break;
case 648:
#line 3849 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes = 0;
}
break;
case 652:
#line 3855 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_BOTS;
}
break;
case 653:
#line 3858 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_CCONN;
}
break;
case 654:
#line 3861 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_NOCTCP;
}
break;
case 655:
#line 3864 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_DEAF;
}
break;
case 656:
#line 3867 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_DEBUG;
}
break;
case 657:
#line 3870 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_FULL;
}
break;
case 658:
#line 3873 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SKILL;
}
break;
case 659:
#line 3876 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_NCHANGE;
}
break;
case 660:
#line 3879 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_REJ;
}
break;
case 661:
#line 3882 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_UNAUTH;
}
break;
case 662:
#line 3885 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SPY;
}
break;
case 663:
#line 3888 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_EXTERNAL;
}
break;
case 664:
#line 3891 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_OPERWALL;
}
break;
case 665:
#line 3894 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SERVNOTICE;
}
break;
case 666:
#line 3897 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_INVISIBLE;
}
break;
case 667:
#line 3900 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_WALLOP;
}
break;
case 668:
#line 3903 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SOFTCALLERID;
}
break;
case 669:
#line 3906 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_CALLERID;
}
break;
case 670:
#line 3909 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_LOCOPS;
}
break;
case 671:
#line 3912 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_HIDECHANNELS;
}
break;
case 672:
#line 3915 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_FARCONNECT;
}
break;
case 673:
#line 3920 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes = 0;
}
break;
case 677:
#line 3926 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_BOTS;
}
break;
case 678:
#line 3929 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_CCONN;
}
break;
case 679:
#line 3932 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_NOCTCP;
}
break;
case 680:
#line 3935 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_DEAF;
}
break;
case 681:
#line 3938 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_DEBUG;
}
break;
case 682:
#line 3941 "ircd_parser.y"
	{ 
  ConfigFileEntry.oper_only_umodes |= UMODE_FULL;
}
break;
case 683:
#line 3944 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SKILL;
}
break;
case 684:
#line 3947 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_NCHANGE;
}
break;
case 685:
#line 3950 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_REJ;
}
break;
case 686:
#line 3953 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_UNAUTH;
}
break;
case 687:
#line 3956 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SPY;
}
break;
case 688:
#line 3959 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_EXTERNAL;
}
break;
case 689:
#line 3962 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_OPERWALL;
}
break;
case 690:
#line 3965 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SERVNOTICE;
}
break;
case 691:
#line 3968 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_INVISIBLE;
}
break;
case 692:
#line 3971 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_WALLOP;
}
break;
case 693:
#line 3974 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SOFTCALLERID;
}
break;
case 694:
#line 3977 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_CALLERID;
}
break;
case 695:
#line 3980 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_LOCOPS;
}
break;
case 696:
#line 3983 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_HIDECHANNELS;
}
break;
case 697:
#line 3986 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_FARCONNECT;
}
break;
case 698:
#line 3991 "ircd_parser.y"
	{
  ConfigFileEntry.min_nonwildcard = yystack.l_mark[-1].number;
}
break;
case 699:
#line 3996 "ircd_parser.y"
	{
  ConfigFileEntry.min_nonwildcard_simple = yystack.l_mark[-1].number;
}
break;
case 700:
#line 4001 "ircd_parser.y"
	{
  ConfigFileEntry.default_floodcount = yystack.l_mark[-1].number;
}
break;
case 701:
#line 4006 "ircd_parser.y"
	{
  ConfigFileEntry.client_flood = yystack.l_mark[-1].number;
}
break;
case 702:
#line 4011 "ircd_parser.y"
	{
  ConfigFileEntry.dot_in_ip6_addr = yylval.number;
}
break;
case 703:
#line 4019 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(GDENY_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 704:
#line 4026 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    /*
     * since we re-allocate yy_conf/yy_aconf after the end of action=, at the
     * end we will have one extra, so we should free it.
     */
    if (yy_conf->name == NULL || yy_aconf->user == NULL)
    {
      delete_conf_item(yy_conf);
      yy_conf = NULL;
      yy_aconf = NULL;
    }
  }
}
break;
case 714:
#line 4052 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.glines = yylval.number;
}
break;
case 715:
#line 4058 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_time = yystack.l_mark[-1].number;
}
break;
case 716:
#line 4064 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_logging = 0;
}
break;
case 720:
#line 4070 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_logging |= GDENY_REJECT;
}
break;
case 721:
#line 4074 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_logging |= GDENY_BLOCK;
}
break;
case 722:
#line 4080 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      struct CollectItem *yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 723:
#line 4114 "ircd_parser.y"
	{
  if (ypass == 2)  
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 724:
#line 4123 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->flags = 0;
}
break;
case 725:
#line 4127 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    dlink_node *ptr, *next_ptr;

    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;

      yy_tmp = ptr->data;
      new_conf = make_conf_item(GDENY_TYPE);
      new_aconf = map_to_conf(new_conf);

      new_aconf->flags = yy_aconf->flags;

      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      else
        DupString(new_conf->name, "*");
      if (yy_aconf->user != NULL)
         DupString(new_aconf->user, yy_tmp->user);
      else   
        DupString(new_aconf->user, "*");
      if (yy_aconf->host != NULL)
        DupString(new_aconf->host, yy_tmp->host);
      else
        DupString(new_aconf->host, "*");

      dlinkDelete(&yy_tmp->node, &col_conf_list);
    }

    /*
     * In case someone has fed us with more than one action= after user/name
     * which would leak memory  -Michael
     */
    if (yy_conf->name == NULL || yy_aconf->user == NULL)
      delete_conf_item(yy_conf);

    yy_conf = make_conf_item(GDENY_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 728:
#line 4174 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->flags |= GDENY_REJECT;
}
break;
case 729:
#line 4178 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->flags |= GDENY_BLOCK;
}
break;
case 755:
#line 4203 "ircd_parser.y"
	{
  ConfigChannel.cycle_on_hostchange = yylval.number;
}
break;
case 756:
#line 4208 "ircd_parser.y"
	{
  ConfigChannel.disable_fake_channels = yylval.number;
}
break;
case 757:
#line 4213 "ircd_parser.y"
	{
  ConfigChannel.restrict_channels = yylval.number;
}
break;
case 758:
#line 4218 "ircd_parser.y"
	{
  ConfigChannel.disable_local_channels = yylval.number;
}
break;
case 759:
#line 4223 "ircd_parser.y"
	{
  ConfigChannel.use_except = yylval.number;
}
break;
case 760:
#line 4228 "ircd_parser.y"
	{
  ConfigChannel.use_invex = yylval.number;
}
break;
case 761:
#line 4233 "ircd_parser.y"
	{
  ConfigChannel.regex_bans = yylval.number;
}
break;
case 762:
#line 4238 "ircd_parser.y"
	{
  ConfigChannel.use_knock = yylval.number;
}
break;
case 763:
#line 4243 "ircd_parser.y"
	{
  ConfigChannel.use_noctcp = yylval.number;
}
break;
case 764:
#line 4248 "ircd_parser.y"
	{
  ConfigChannel.knock_delay = yystack.l_mark[-1].number;
}
break;
case 765:
#line 4253 "ircd_parser.y"
	{
  ConfigChannel.knock_delay_channel = yystack.l_mark[-1].number;
}
break;
case 766:
#line 4258 "ircd_parser.y"
	{
  ConfigChannel.max_chans_per_user = yystack.l_mark[-1].number;
}
break;
case 767:
#line 4263 "ircd_parser.y"
	{
  ConfigChannel.quiet_on_ban = yylval.number;
}
break;
case 768:
#line 4268 "ircd_parser.y"
	{
  ConfigChannel.max_bans = yystack.l_mark[-1].number;
}
break;
case 769:
#line 4273 "ircd_parser.y"
	{
  ConfigChannel.default_split_user_count = yystack.l_mark[-1].number;
}
break;
case 770:
#line 4278 "ircd_parser.y"
	{
  ConfigChannel.default_split_server_count = yystack.l_mark[-1].number;
}
break;
case 771:
#line 4283 "ircd_parser.y"
	{
  ConfigChannel.no_create_on_split = yylval.number;
}
break;
case 772:
#line 4288 "ircd_parser.y"
	{
  ConfigChannel.no_join_on_split = yylval.number;
}
break;
case 773:
#line 4293 "ircd_parser.y"
	{
  ConfigChannel.burst_topicwho = yylval.number;
}
break;
case 774:
#line 4298 "ircd_parser.y"
	{
  GlobalSetOptions.joinfloodcount = yylval.number;
}
break;
case 775:
#line 4303 "ircd_parser.y"
	{
  GlobalSetOptions.joinfloodtime = yylval.number;
}
break;
case 787:
#line 4322 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.flatten_links = yylval.number;
}
break;
case 788:
#line 4328 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.hide_servers = yylval.number;
}
break;
case 789:
#line 4334 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigServerHide.hidden_name);
    DupString(ConfigServerHide.hidden_name, yylval.string);
  }
}
break;
case 790:
#line 4343 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if ((yystack.l_mark[-1].number > 0) && ConfigServerHide.links_disabled == 1)
    {
      eventAddIsh("write_links_file", write_links_file, NULL, yystack.l_mark[-1].number);
      ConfigServerHide.links_disabled = 0;
    }

    ConfigServerHide.links_delay = yystack.l_mark[-1].number;
  }
}
break;
case 791:
#line 4357 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.hidden = yylval.number;
}
break;
case 792:
#line 4363 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.disable_hidden = yylval.number;
}
break;
case 793:
#line 4369 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.hide_server_ips = yylval.number;
}
break;
#line 6967 "y.tab.c"
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
        if (yychar < 0)
        {
            if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yystack.s_mark, yystate);
#endif
    if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
    {
        goto yyoverflow;
    }
    *++yystack.s_mark = (short) yystate;
    *++yystack.l_mark = yyval;
    goto yyloop;

yyoverflow:
    yyerror("yacc stack overflow");

yyabort:
    yyfreestack(&yystack);
    return (1);

yyaccept:
    yyfreestack(&yystack);
    return (0);
}
